(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    170940,       4172]
NotebookOptionsPosition[    167865,       4067]
NotebookOutlinePosition[    168209,       4082]
CellTagsIndexPosition[    168166,       4079]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Methoden der Bioinformatik",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox[" \n\n",
  FontSize->12],
 "Eine Einf\[UDoubleDot]hrung zur Anwendung in Biologie und Medizin\n\n2. \
Auflage",
 StyleBox["\n",
  FontSize->18,
  FontWeight->"Bold"],
 StyleBox["\n",
  FontSize->12],
 "Marc-Thorsten H\[UDoubleDot]tt",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "und",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "Manuel Dehnert\n",
 StyleBox["\n",
  FontSize->12],
 "Springer Spektrum",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "2006",
 StyleBox[", ",
  FontSize->12,
  FontWeight->"Bold"],
 "2016, ISBN 978-3-662-46149-5"
}], "Subsubtitle",
 CellChangeTimes->{{3.669868691792925*^9, 3.669868786167323*^9}, {
  3.6698688284727426`*^9, 3.669868879042635*^9}, {3.6698691142260866`*^9, 
  3.6698691148331213`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs: ",
 "Zerlegung der Einheit"
}], "Subtitle",
 CellChangeTimes->{3.670321495640956*^9, 3.670321893142056*^9, 
  3.671607701886611*^9},
 Background->RGBColor[
  0.8705882352941177, 0.00392156862745098, 0.2196078431372549]],

Cell[TextData[{
 "Im Rahmen dieses Exkurses soll das prinzipielle Ph\[ADoubleDot]nomen der \
Zerlegung des Einheitsintervalls durch eine diskrete \
Wahrscheinlichkeitsverteilung und die in Abb. 2.3 dargestellte Abfolge von \
Schritten zur praktischen Verwendung dieser Vorstellung in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " rekonstruiert werden.\n\nDas erste Element auf diesem Weg ist eine \
geeignete Wahrscheinlichkeitsverteilung. Dazu wird mit der Funktion ",
 StyleBox["RandomReal[]",
  FontWeight->"Bold"],
 ", die eine im Intervall [0, 1] gleichverteilte reellwertige Zufallszahl \
erzeugt, der Ausgangspunkt gelegt:"
}], "Text",
 CellChangeTimes->{{3.6745561378893833`*^9, 3.6745561525094047`*^9}, {
  3.6745561997754726`*^9, 3.6745562273485126`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rand", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"RandomReal", "[", "]"}], ",", 
    RowBox[{"{", "6", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6228761568489103`*^9, 3.6228761574245653`*^9}, {
  3.622876224604412*^9, 3.62287624848002*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.2571268392964543`", ",", "0.957978120500389`", ",", "0.968370342960821`",
    ",", "0.3552059716242548`", ",", "0.5592918270611447`", ",", 
   "0.9408964252927301`"}], "}"}]], "Output",
 CellChangeTimes->{3.677570307477867*^9}]
}, Open  ]],

Cell["\<\
Diese Tabelle aus sechs Zufallszahlen l\[ADoubleDot]sst sich nun so \
normieren, dass die Summe gerade Eins ist:\
\>", "Text",
 CellChangeTimes->{{3.6745563495966883`*^9, 3.6745563631887083`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"probDist", "=", 
  RowBox[{"rand", "/", 
   RowBox[{"Apply", "[", 
    RowBox[{"Plus", ",", "rand"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.06366307145956847`", ",", "0.23718966759360136`", ",", 
   "0.23976271987757325`", ",", "0.08794687950995327`", ",", 
   "0.138477319794275`", ",", "0.23296034176502867`"}], "}"}]], "Output",
 CellChangeTimes->{3.6775703075870667`*^9}]
}, Open  ]],

Cell[TextData[{
 "Die Funktion ",
 StyleBox["Plus",
  FontWeight->"Bold"],
 " gibt die Summe ihrer Argumente aus, ",
 StyleBox["Plus[x1, x2, x3]",
  FontWeight->"Bold"],
 "= x1 + x2 + x3. Um die Funktion ",
 StyleBox["Plus",
  FontWeight->"Bold"],
 " auf eine Liste von Elementen anzuwenden, ist der Befehl ",
 StyleBox["Apply",
  FontWeight->"Bold"],
 " n\[ODoubleDot]tig. ",
 StyleBox["Plus[{x1, x2, x3}]",
  FontWeight->"Bold"],
 " w\[UDoubleDot]rde das Argument unausgewertet lassen, erst ",
 StyleBox["Apply[Plus, {x1, x2, x3}]",
  FontWeight->"Bold"],
 " f\[UDoubleDot]hrt auf x1 + x2 + x3. Mit dem Anwenden der Funktion ",
 StyleBox["Plus",
  FontWeight->"Bold"],
 " auf die resultierende Liste,"
}], "Text",
 CellChangeTimes->{{3.674556390546747*^9, 3.6745564262227983`*^9}, {
  3.6745564958198996`*^9, 3.6745565156279287`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Apply", "[", 
  RowBox[{"Plus", ",", "probDist"}], "]"}]], "Input"],

Cell[BoxData["1.`"], "Output",
 CellChangeTimes->{3.677570307618267*^9}]
}, Open  ]],

Cell[TextData[{
 "l\[ADoubleDot]sst sich diese Normierung \[UDoubleDot]berpr\[UDoubleDot]fen. \
Eine Abk\[UDoubleDot]rzung dieses ",
 StyleBox["Apply",
  FontWeight->"Bold"],
 "-Befehls ist durch",
 StyleBox[" @@",
  FontWeight->"Bold"],
 " gegeben:"
}], "Text",
 CellChangeTimes->{{3.6745565400359635`*^9, 3.6745565599269924`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plus", "@@", "probDist"}]], "Input"],

Cell[BoxData["1.`"], "Output",
 CellChangeTimes->{3.6775703076338673`*^9}]
}, Open  ]],

Cell[TextData[{
 "Damit sind die einzelnen Intervallgr\[ODoubleDot]\[SZ]en festgelegt. Durch \
Bildung der Partialsummen\n\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["q", "i"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"j", "=", "1"}], "i"], 
    SubscriptBox["p", "j"]}], TraditionalForm]]],
 "\n\nerh\[ADoubleDot]lt man daraus die Intervallgrenzen im Einheitsintervall \
[0, 1]. In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " sind Partialsummen effizient zu formulieren, indem man die Funktion ",
 StyleBox["Plus",
  FontWeight->"Bold"],
 " iterativ auf eine Liste anwendet. Dazu verwenden wir die Funktion ",
 StyleBox["FoldList",
  FontWeight->"Bold"],
 ". Diese Funktion besitzt drei Argumente, n\[ADoubleDot]mlich eine \
zweiargumentige Funktion ",
 StyleBox["f",
  FontSlant->"Italic"],
 ", das Anfangselement ",
 StyleBox["A",
  FontSlant->"Italic"],
 " und eine Liste ",
 StyleBox["L",
  FontSlant->"Italic"],
 " = {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", . . . , ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "n"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "}. Dann hat man\n\n",
 StyleBox["FoldList[f, A, L] ",
  FontWeight->"Bold"],
 "= {",
 StyleBox["A",
  FontSlant->"Italic"],
 ", ",
 StyleBox["f",
  FontSlant->"Italic"],
 " [",
 StyleBox["A",
  FontSlant->"Italic"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]]],
 "], f [ f [",
 StyleBox["A",
  FontSlant->"Italic"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]]],
 "], ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]]],
 "], . . . }. \n\nDie Iteration endet, wenn das letzte Listenelement erreicht \
ist. In unserem Fall bildet die untere Intervallgrenze, ",
 StyleBox["A",
  FontSlant->"Italic"],
 " = 0, den Anfangspunkt. Man hat also"
}], "Text",
 CellChangeTimes->{{3.67455661374107*^9, 3.674556619547078*^9}, {
   3.674556659752136*^9, 3.6745566704501514`*^9}, {3.674556708544206*^9, 
   3.674556709685208*^9}, 3.6745567547462745`*^9, {3.6745567852403183`*^9, 
   3.674556817508365*^9}, {3.674556878050453*^9, 3.674556922113517*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cumDist", "=", 
  RowBox[{"FoldList", "[", 
   RowBox[{"Plus", ",", "0", ",", "probDist"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0.06366307145956847`", ",", "0.30085273905316984`", ",", 
   "0.540615458930743`", ",", "0.6285623384406963`", ",", 
   "0.7670396582349713`", ",", "1.`"}], "}"}]], "Output",
 CellChangeTimes->{3.677570307649467*^9}]
}, Open  ]],

Cell["In eine grafische Darstellung des Einheitsintervalls,", "Text",
 CellChangeTimes->{{3.6745569356015363`*^9, 3.67455695106456*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pl1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{"0", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"Axes", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1.01"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6228763324212017`*^9, 3.622876356334062*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJxF0X0s1AEcBvDDVnmdLKefGZFsmBinTUUqkXSVO6ImmbdlFC1aV21NOkte
IlbRaXROJXMnKhXuOHMqOs4dN113Tuf9cjHHZl6qrb7fZ3v27PP34xifTksy
JJFI1D/9u8eSpgYE05EBpH+ZbDgdryIoB/6bbCoraiKCwLv9tnEqiQjw3n4f
3gMiESx4IvQtJDLBOdn51+4Rd8CJmToijygDbykLrf41XwN+1+8dEmLPBUfn
KEaE+c3g9MYrHo8X34MXiod6DAz44J6Obr54fyc4hRFqfkbbBe4w9t6ovygC
17K71m13fQYHktue0Rt6wR4iRUu3mxgsDaTPvZzrB6eZpEpkXhLwF3lUm0XR
IJgeHK3WaKTgPVX5UVXOQ+DR9VLphVvD4PFQMZsslIN55SrGgOMImHPXKM/1
+jewPuHsTPJHBdg0KJfWaKME37QcN1PHqMBm7e6kYeoo2P/qyTXhCppVU8De
yVKDYyMpfcZhY+A3sqTS9iW0Xy/PcOLhD/COI8n60iAN2JfiW9I8gVYtFH5i
M8fBWp9wJuE9AXaZ9ZgxGER3OWdJMrInwfelsgSa8xRYRxeUGHahX0daH/a7
PA1m9+VUjlnNgJdFMTesOtGjJXy95aVZ8NLAPuK2hRacUeYkYLSibfqcLDWx
P/FfWf2q3Tp64Xx1mqJuDsyP4zItjuvAH8RpYcoT6LcBblsbwtH1dhwWNQpd
Ia9oKohHZ53KVZsw0O6B5/w316JduLZGwy/QTvbyntpX6O2rtIjgRvSmlqOp
zFa02pNSbjSIVjydjx2UoeXmXGe2HP111pV3SIlufe4gyp5Gt5C/F4Rr0U3M
CpqjDl2XYK0ULKI5Egm7eBlddbA4JW4FzeJRPb3W0I8cTPUbG+jf5AtD6w==

      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 1.01}, {-1, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6775703078678675`*^9}]
}, Open  ]],

Cell["lassen sich nun diese Intervallgrenzen einzeichnen:", "Text",
 CellChangeTimes->{{3.6745569703755884`*^9, 3.6745569821226053`*^9}}],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"plX", "[", "k", "]"}], "=", 
     RowBox[{"ListLinePlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"cumDist", "[", 
            RowBox[{"[", "k", "]"}], "]"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"cumDist", "[", 
            RowBox[{"[", "k", "]"}], "]"}], ",", "0.2"}], "}"}]}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"AbsoluteThickness", "[", "3", "]"}], ",", "Black"}], 
         "}"}]}]}], "]"}]}], "\[IndentingNewLine]", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "1", ",", 
     RowBox[{"Length", "[", "cumDist", "]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.56870862184375*^9, 3.56870864003125*^9}, {
  3.568708747640625*^9, 3.568708764953125*^9}, {3.568710409953125*^9, 
  3.568710422046875*^9}, {3.6228763984854717`*^9, 3.622876402070837*^9}, {
  3.622876466732905*^9, 3.622876496970731*^9}}],

Cell[TextData[{
 "Die ",
 StyleBox["Do",
  FontWeight->"Bold"],
 "-Schleife ist ein zentrales Element der Programmierung in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". Die erste geschweifte Klammer enth\[ADoubleDot]lt die Abfolge von \
Befehlen, die in jedem Schleifenschritt ausgef\[UDoubleDot]hrt werden. In \
unserem Beispiel enth\[ADoubleDot]lt sie nur einen einzigen Befehl. Die \
zweite Klammer legt die Schleifenvariable (hier: ",
 StyleBox["k",
  FontWeight->"Bold"],
 ") und ihren Anfangs- und Endwert in der Schleife fest. Es ist deutlich zu \
sehen, dass in den Befehlen (erste Klammer) diese Variable verwendet werden \
kann."
}], "Text",
 CellChangeTimes->{
  3.6745570288556724`*^9, {3.6745570627807217`*^9, 3.674557065171725*^9}, {
   3.6745570973327713`*^9, 3.6745571213848057`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pl00", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{"pl1", ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"plX", "[", "k", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", 
          RowBox[{"Length", "[", "cumDist", "]"}]}], "}"}]}], "]"}]}], "}"}], 
    "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.56871047771875*^9, 3.568710482921875*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJxF0X0s1AEcBvDDVnmdLKefGZFsmBinTUUqkXSVO6ImmbdlFC1aV21NOkte
IlbRaXROJXMnKhXuOHMqOs4dN113Tuf9cjHHZl6qrb7fZ3v27PP34xifTksy
JJFI1D/9u8eSpgYE05EBpH+ZbDgdryIoB/6bbCoraiKCwLv9tnEqiQjw3n4f
3gMiESx4IvQtJDLBOdn51+4Rd8CJmToijygDbykLrf41XwN+1+8dEmLPBUfn
KEaE+c3g9MYrHo8X34MXiod6DAz44J6Obr54fyc4hRFqfkbbBe4w9t6ovygC
17K71m13fQYHktue0Rt6wR4iRUu3mxgsDaTPvZzrB6eZpEpkXhLwF3lUm0XR
IJgeHK3WaKTgPVX5UVXOQ+DR9VLphVvD4PFQMZsslIN55SrGgOMImHPXKM/1
+jewPuHsTPJHBdg0KJfWaKME37QcN1PHqMBm7e6kYeoo2P/qyTXhCppVU8De
yVKDYyMpfcZhY+A3sqTS9iW0Xy/PcOLhD/COI8n60iAN2JfiW9I8gVYtFH5i
M8fBWp9wJuE9AXaZ9ZgxGER3OWdJMrInwfelsgSa8xRYRxeUGHahX0daH/a7
PA1m9+VUjlnNgJdFMTesOtGjJXy95aVZ8NLAPuK2hRacUeYkYLSibfqcLDWx
P/FfWf2q3Tp64Xx1mqJuDsyP4zItjuvAH8RpYcoT6LcBblsbwtH1dhwWNQpd
Ia9oKohHZ53KVZsw0O6B5/w316JduLZGwy/QTvbyntpX6O2rtIjgRvSmlqOp
zFa02pNSbjSIVjydjx2UoeXmXGe2HP111pV3SIlufe4gyp5Gt5C/F4Rr0U3M
CpqjDl2XYK0ULKI5Egm7eBlddbA4JW4FzeJRPb3W0I8cTPUbG+jf5AtD6w==

       "]]}}, {}}, {{}, {{}, {}, 
     {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[3], 
      LineBox[{{0., 0.}, {0., 0.2}}]}}, {}}, {{}, {{}, {}, 
     {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[3], 
      LineBox[{{0.06366307145956847, 0.}, {0.06366307145956847, 
       0.2}}]}}, {}}, {{}, {{}, {}, 
     {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[3], 
      LineBox[{{0.30085273905316984`, 0.}, {0.30085273905316984`, 
       0.2}}]}}, {}}, {{}, {{}, {}, 
     {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[3], 
      LineBox[{{0.540615458930743, 0.}, {0.540615458930743, 
       0.2}}]}}, {}}, {{}, {{}, {}, 
     {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[3], 
      LineBox[{{0.6285623384406963, 0.}, {0.6285623384406963, 
       0.2}}]}}, {}}, {{}, {{}, {}, 
     {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[3], 
      LineBox[{{0.7670396582349713, 0.}, {0.7670396582349713, 
       0.2}}]}}, {}}, {{}, {{}, {}, 
     {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[3], 
      LineBox[{{1., 0.}, {1., 0.2}}]}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 1.01}, {-1, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.677570308211068*^9}]
}, Open  ]],

Cell[TextData[{
 "Die Ausf\[UDoubleDot]hrung der beiden letztgenannten Befehle ergibt die \
ersten Teile der Abb. 2.3. Die hier verwendeten Grafikoptionen eignen sich \
besonders f\[UDoubleDot]r eigene kleine Experimente mit den ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Befehlen. Eine Zufallszahl"
}], "Text",
 CellChangeTimes->{{3.6745571432728376`*^9, 3.674557185634899*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x", "=", 
  RowBox[{"RandomReal", "[", "]"}]}]], "Input",
 CellChangeTimes->{{3.622876525317309*^9, 3.622876525917012*^9}, 
   3.622876559158989*^9, {3.6745577967047834`*^9, 3.6745578235448227`*^9}}],

Cell[BoxData["0.2111093553782457`"], "Output",
 CellChangeTimes->{3.677570308273468*^9}]
}, Open  ]],

Cell["kann nun in diese Abbildung eingetragen werden:", "Text",
 CellChangeTimes->{{3.674557536089405*^9, 3.674557556987435*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pl2", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0"}], "}"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"AbsolutePointSize", "[", "8", "]"}], ",", "Red"}], "}"}]}]}],
     "]"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", 
  RowBox[{"pl00", ",", "pl2"}], "]"}]}], "Input",
 CellChangeTimes->{{3.56871052021875*^9, 3.568710555671875*^9}, {
  3.622876571758478*^9, 3.622876599720792*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJxF0X0s1AEcBvDDVnmdLKefGZFsmBinTUUqkXSVO6ImmbdlFC1aV21NOkte
IlbRaXROJXMnKhXuOHMqOs4dN113Tuf9cjHHZl6qrb7fZ3v27PP34xifTksy
JJFI1D/9u8eSpgYE05EBpH+ZbDgdryIoB/6bbCoraiKCwLv9tnEqiQjw3n4f
3gMiESx4IvQtJDLBOdn51+4Rd8CJmToijygDbykLrf41XwN+1+8dEmLPBUfn
KEaE+c3g9MYrHo8X34MXiod6DAz44J6Obr54fyc4hRFqfkbbBe4w9t6ovygC
17K71m13fQYHktue0Rt6wR4iRUu3mxgsDaTPvZzrB6eZpEpkXhLwF3lUm0XR
IJgeHK3WaKTgPVX5UVXOQ+DR9VLphVvD4PFQMZsslIN55SrGgOMImHPXKM/1
+jewPuHsTPJHBdg0KJfWaKME37QcN1PHqMBm7e6kYeoo2P/qyTXhCppVU8De
yVKDYyMpfcZhY+A3sqTS9iW0Xy/PcOLhD/COI8n60iAN2JfiW9I8gVYtFH5i
M8fBWp9wJuE9AXaZ9ZgxGER3OWdJMrInwfelsgSa8xRYRxeUGHahX0daH/a7
PA1m9+VUjlnNgJdFMTesOtGjJXy95aVZ8NLAPuK2hRacUeYkYLSibfqcLDWx
P/FfWf2q3Tp64Xx1mqJuDsyP4zItjuvAH8RpYcoT6LcBblsbwtH1dhwWNQpd
Ia9oKohHZ53KVZsw0O6B5/w316JduLZGwy/QTvbyntpX6O2rtIjgRvSmlqOp
zFa02pNSbjSIVjydjx2UoeXmXGe2HP111pV3SIlufe4gyp5Gt5C/F4Rr0U3M
CpqjDl2XYK0ULKI5Egm7eBlddbA4JW4FzeJRPb3W0I8cTPUbG+jf5AtD6w==

        "]]}}, {}}, {{}, {{}, {}, 
      {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[3], 
       LineBox[{{0., 0.}, {0., 0.2}}]}}, {}}, {{}, {{}, {}, 
      {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[3], 
       LineBox[{{0.06366307145956847, 0.}, {0.06366307145956847, 
        0.2}}]}}, {}}, {{}, {{}, {}, 
      {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[3], 
       LineBox[{{0.30085273905316984`, 0.}, {0.30085273905316984`, 
        0.2}}]}}, {}}, {{}, {{}, {}, 
      {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[3], 
       LineBox[{{0.540615458930743, 0.}, {0.540615458930743, 
        0.2}}]}}, {}}, {{}, {{}, {}, 
      {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[3], 
       LineBox[{{0.6285623384406963, 0.}, {0.6285623384406963, 
        0.2}}]}}, {}}, {{}, {{}, {}, 
      {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[3], 
       LineBox[{{0.7670396582349713, 0.}, {0.7670396582349713, 
        0.2}}]}}, {}}, {{}, {{}, {}, 
      {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[3], 
       LineBox[{{1., 0.}, {1., 0.2}}]}}, {}}}, {{}, {{}, 
     {RGBColor[1, 0, 0], AbsolutePointSize[8], AbsoluteThickness[1.6], 
      PointBox[{{0.2111093553782457, 0.}, {0.2111093553782457, 
       0.}}]}, {}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 1.01}, {-1, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.677570308351468*^9}]
}, Open  ]],

Cell[TextData[{
 "Das zugeh\[ODoubleDot]rige Ergebnis, also die Intervallnummer oder \[Dash] \
in dem Gedankenexperiment dieses Kapitels \[Dash] die von dem \
W\[UDoubleDot]rfel, der dieser Wahrscheinlichkeitsverteilung folgt, \
ausgegebene Zahl, kann man nun \[UDoubleDot]ber einen kleinen Umweg \
ermitteln. Dazu f\[UDoubleDot]gt man die Zahl ",
 StyleBox["x",
  FontWeight->"Bold"],
 " der Liste von Intervallgrenzen hinzu (mit ",
 StyleBox["Append",
  FontWeight->"Bold"],
 "), sortiert die Eintr\[ADoubleDot]ge dieser Liste nach ihrer \
Gr\[ODoubleDot]\[SZ]e (mit ",
 StyleBox["Sort",
  FontWeight->"Bold"],
 ") und l\[ADoubleDot]sst sich die Position von ",
 StyleBox["x",
  FontWeight->"Bold"],
 " in der sortierten Liste ausgeben (mit ",
 StyleBox["Position",
  FontWeight->"Bold"],
 "). Subtrahiert man 1 (sonst w\[UDoubleDot]rden die m\[ODoubleDot]glichen \
Ergebnisse zwischen 2 und 7 liegen), so erh\[ADoubleDot]lt man die \
Intervallnummer:"
}], "Text",
 CellChangeTimes->{{3.674558406389284*^9, 3.674558415595742*^9}, 
   3.6745584470868173`*^9, {3.677562143857747*^9, 3.6775621603001757`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Position", "[", 
    RowBox[{
     RowBox[{"Sort", "[", 
      RowBox[{"Append", "[", 
       RowBox[{"cumDist", ",", "x"}], "]"}], "]"}], ",", "x"}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}], " ", "-", "1"}]], "Input",
 CellChangeTimes->{{3.6228765909351883`*^9, 3.622876592604402*^9}}],

Cell[BoxData["2"], "Output",
 CellChangeTimes->{3.6775703083826685`*^9}]
}, Open  ]],

Cell[TextData[{
 "Damit haben wir Abb. 2.3 vollst\[ADoubleDot]ndig in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " reproduziert. Zugleich haben wir ein mathematisch nicht triviales Objekt \
implementiert, n\[ADoubleDot]mlich eine Routine, die eine zwischen Null und \
Eins gleichverteilte kontinuierliche Zufallszahl in eine diskrete Zufallszahl \
\[UDoubleDot]berf\[UDoubleDot]hrt, die einer vorgegebenen \
Wahrscheinlichkeitsverteilung folgt. Diese Aussage k\[ODoubleDot]nnen wir nun \
\[UDoubleDot]berpr\[UDoubleDot]fen. Abbildung 2.4 gibt eine Abfolge von zehn \
Zufallsexperimenten mit jeweils zehn Eintr\[ADoubleDot]gen an. Die \
erheblichen Unterschiede zwischen den Punktverteilungen zeigen deutlich, dass \
zehn Wiederholungen keinesfalls ausreichen, um die zugrunde liegende \
Wahrscheinlichkeitsverteilung angemessen abzubilden. "
}], "Text",
 CellChangeTimes->{
  3.6745585660589886`*^9, {3.674558597741034*^9, 3.6745586263770757`*^9}, {
   3.677488962340289*^9, 3.6774889721215057`*^9}, 3.6774895510685244`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"plTab", "[", "j", "]"}], "=", 
      RowBox[{"Map", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"{", 
             RowBox[{"#", ",", "0"}], "}"}], "}"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"AbsolutePointSize", "[", "6", "]"}], ",", "Red"}], 
             "}"}]}]}], "]"}], "&"}], ",", " ", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"RandomReal", "[", "]"}], ",", 
          RowBox[{"{", "10", "}"}]}], "]"}]}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "10"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.56871072096875*^9, 3.56871077609375*^9}, {
  3.56871083884375*^9, 3.568710853875*^9}, {3.568710915265625*^9, 
  3.5687110126875*^9}, {3.568711045015625*^9, 3.568711048125*^9}, {
  3.5687111038125*^9, 3.5687111068125*^9}, {3.622876743846044*^9, 
  3.622876759465187*^9}, {3.622876939409384*^9, 3.622876940903063*^9}, {
  3.6228772251412773`*^9, 3.62287722549816*^9}, {3.6775560865842056`*^9, 
  3.677556101763032*^9}, {3.677562316625451*^9, 3.6775623203070574`*^9}, {
  3.6775624392114663`*^9, 3.677562460318303*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{"{", 
          RowBox[{"pl00", ",", 
           RowBox[{"plTab", "[", "j", "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"AspectRatio", "\[Rule]", "0.1"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", "10"}], "}"}]}], "]"}], "}"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6228770752103167`*^9, 3.6228771743454103`*^9}, {
  3.6775560835890007`*^9, 3.6775560905154123`*^9}, {3.6775623224442616`*^9, 
  3.6775623241446643`*^9}, {3.6775624455450773`*^9, 3.677562449023884*^9}, {
  3.67756252642062*^9, 3.6775625375122395`*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{{{}, {}, 
          {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
           Opacity[1.], LineBox[CompressedData["
1:eJxF0X0s1AEcBvDDVnmdLKefGZFsmBinTUUqkXSVO6ImmbdlFC1aV21NOkte
IlbRaXROJXMnKhXuOHMqOs4dN113Tuf9cjHHZl6qrb7fZ3v27PP34xifTksy
JJFI1D/9u8eSpgYE05EBpH+ZbDgdryIoB/6bbCoraiKCwLv9tnEqiQjw3n4f
3gMiESx4IvQtJDLBOdn51+4Rd8CJmToijygDbykLrf41XwN+1+8dEmLPBUfn
KEaE+c3g9MYrHo8X34MXiod6DAz44J6Obr54fyc4hRFqfkbbBe4w9t6ovygC
17K71m13fQYHktue0Rt6wR4iRUu3mxgsDaTPvZzrB6eZpEpkXhLwF3lUm0XR
IJgeHK3WaKTgPVX5UVXOQ+DR9VLphVvD4PFQMZsslIN55SrGgOMImHPXKM/1
+jewPuHsTPJHBdg0KJfWaKME37QcN1PHqMBm7e6kYeoo2P/qyTXhCppVU8De
yVKDYyMpfcZhY+A3sqTS9iW0Xy/PcOLhD/COI8n60iAN2JfiW9I8gVYtFH5i
M8fBWp9wJuE9AXaZ9ZgxGER3OWdJMrInwfelsgSa8xRYRxeUGHahX0daH/a7
PA1m9+VUjlnNgJdFMTesOtGjJXy95aVZ8NLAPuK2hRacUeYkYLSibfqcLDWx
P/FfWf2q3Tp64Xx1mqJuDsyP4zItjuvAH8RpYcoT6LcBblsbwtH1dhwWNQpd
Ia9oKohHZ53KVZsw0O6B5/w316JduLZGwy/QTvbyntpX6O2rtIjgRvSmlqOp
zFa02pNSbjSIVjydjx2UoeXmXGe2HP111pV3SIlufe4gyp5Gt5C/F4Rr0U3M
CpqjDl2XYK0ULKI5Egm7eBlddbA4JW4FzeJRPb3W0I8cTPUbG+jf5AtD6w==

            "]]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0., 0.}, {0., 0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.06366307145956847, 0.}, {0.06366307145956847, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.30085273905316984`, 0.}, {0.30085273905316984`, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.540615458930743, 0.}, {0.540615458930743, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], 
           LineBox[{{0.6285623384406963, 0.}, {0.6285623384406963, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.7670396582349713, 0.}, {0.7670396582349713, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{1., 0.}, {1., 0.2}}]}}, {}}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.7173402518067029, 0.}, {0.7173402518067029, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.3405157238437264, 0.}, {0.3405157238437264, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.27144832384391715`, 0.}, {0.27144832384391715`, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.4357276857100749, 0.}, {0.4357276857100749, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.953936661164617, 0.}, {0.953936661164617, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.9950401212401396, 0.}, {0.9950401212401396, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.3693315489401696, 0.}, {0.3693315489401696, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.42547328522252803`, 0.}, {0.42547328522252803`, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.6844067810271464, 0.}, {0.6844067810271464, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.6708675062716878, 0.}, {0.6708675062716878, 
           0.}}]}, {}}, {}}},
      AspectRatio->0.1,
      Axes->{True, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None},
      PlotRange->{{0, 1.01}, {-1, 1}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -19.636363636363637`}, 
     ImageScaled[{0.5, 0.5}], {360., 36.00000000000001}], InsetBox[
     GraphicsBox[{{{{{}, {}, 
          {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
           Opacity[1.], LineBox[CompressedData["
1:eJxF0X0s1AEcBvDDVnmdLKefGZFsmBinTUUqkXSVO6ImmbdlFC1aV21NOkte
IlbRaXROJXMnKhXuOHMqOs4dN113Tuf9cjHHZl6qrb7fZ3v27PP34xifTksy
JJFI1D/9u8eSpgYE05EBpH+ZbDgdryIoB/6bbCoraiKCwLv9tnEqiQjw3n4f
3gMiESx4IvQtJDLBOdn51+4Rd8CJmToijygDbykLrf41XwN+1+8dEmLPBUfn
KEaE+c3g9MYrHo8X34MXiod6DAz44J6Obr54fyc4hRFqfkbbBe4w9t6ovygC
17K71m13fQYHktue0Rt6wR4iRUu3mxgsDaTPvZzrB6eZpEpkXhLwF3lUm0XR
IJgeHK3WaKTgPVX5UVXOQ+DR9VLphVvD4PFQMZsslIN55SrGgOMImHPXKM/1
+jewPuHsTPJHBdg0KJfWaKME37QcN1PHqMBm7e6kYeoo2P/qyTXhCppVU8De
yVKDYyMpfcZhY+A3sqTS9iW0Xy/PcOLhD/COI8n60iAN2JfiW9I8gVYtFH5i
M8fBWp9wJuE9AXaZ9ZgxGER3OWdJMrInwfelsgSa8xRYRxeUGHahX0daH/a7
PA1m9+VUjlnNgJdFMTesOtGjJXy95aVZ8NLAPuK2hRacUeYkYLSibfqcLDWx
P/FfWf2q3Tp64Xx1mqJuDsyP4zItjuvAH8RpYcoT6LcBblsbwtH1dhwWNQpd
Ia9oKohHZ53KVZsw0O6B5/w316JduLZGwy/QTvbyntpX6O2rtIjgRvSmlqOp
zFa02pNSbjSIVjydjx2UoeXmXGe2HP111pV3SIlufe4gyp5Gt5C/F4Rr0U3M
CpqjDl2XYK0ULKI5Egm7eBlddbA4JW4FzeJRPb3W0I8cTPUbG+jf5AtD6w==

            "]]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0., 0.}, {0., 0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.06366307145956847, 0.}, {0.06366307145956847, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.30085273905316984`, 0.}, {0.30085273905316984`, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.540615458930743, 0.}, {0.540615458930743, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.6285623384406963, 0.}, {0.6285623384406963, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.7670396582349713, 0.}, {0.7670396582349713, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{1., 0.}, {1., 0.2}}]}}, {}}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.5011796829545967, 0.}, {0.5011796829545967, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.2890708806223057, 0.}, {0.2890708806223057, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.3365992591081157, 0.}, {0.3365992591081157, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.13281012638152356`, 0.}, {0.13281012638152356`, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.6671902058069321, 0.}, {0.6671902058069321, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.0966120006903668, 0.}, {0.0966120006903668, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.29160970143565557`, 0.}, {0.29160970143565557`, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.6971289294307803, 0.}, {0.6971289294307803, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.5715839009713362, 0.}, {0.5715839009713362, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.5431469564858882, 0.}, {0.5431469564858882, 
           0.}}]}, {}}, {}}},
      AspectRatio->0.1,
      Axes->{True, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None},
      PlotRange->{{0, 1.01}, {-1, 1}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -58.90909090909091}, 
     ImageScaled[{0.5, 0.5}], {360., 36.}], InsetBox[
     GraphicsBox[{{{{{}, {}, 
          {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
           Opacity[1.], LineBox[CompressedData["
1:eJxF0X0s1AEcBvDDVnmdLKefGZFsmBinTUUqkXSVO6ImmbdlFC1aV21NOkte
IlbRaXROJXMnKhXuOHMqOs4dN113Tuf9cjHHZl6qrb7fZ3v27PP34xifTksy
JJFI1D/9u8eSpgYE05EBpH+ZbDgdryIoB/6bbCoraiKCwLv9tnEqiQjw3n4f
3gMiESx4IvQtJDLBOdn51+4Rd8CJmToijygDbykLrf41XwN+1+8dEmLPBUfn
KEaE+c3g9MYrHo8X34MXiod6DAz44J6Obr54fyc4hRFqfkbbBe4w9t6ovygC
17K71m13fQYHktue0Rt6wR4iRUu3mxgsDaTPvZzrB6eZpEpkXhLwF3lUm0XR
IJgeHK3WaKTgPVX5UVXOQ+DR9VLphVvD4PFQMZsslIN55SrGgOMImHPXKM/1
+jewPuHsTPJHBdg0KJfWaKME37QcN1PHqMBm7e6kYeoo2P/qyTXhCppVU8De
yVKDYyMpfcZhY+A3sqTS9iW0Xy/PcOLhD/COI8n60iAN2JfiW9I8gVYtFH5i
M8fBWp9wJuE9AXaZ9ZgxGER3OWdJMrInwfelsgSa8xRYRxeUGHahX0daH/a7
PA1m9+VUjlnNgJdFMTesOtGjJXy95aVZ8NLAPuK2hRacUeYkYLSibfqcLDWx
P/FfWf2q3Tp64Xx1mqJuDsyP4zItjuvAH8RpYcoT6LcBblsbwtH1dhwWNQpd
Ia9oKohHZ53KVZsw0O6B5/w316JduLZGwy/QTvbyntpX6O2rtIjgRvSmlqOp
zFa02pNSbjSIVjydjx2UoeXmXGe2HP111pV3SIlufe4gyp5Gt5C/F4Rr0U3M
CpqjDl2XYK0ULKI5Egm7eBlddbA4JW4FzeJRPb3W0I8cTPUbG+jf5AtD6w==

            "]]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0., 0.}, {0., 0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.06366307145956847, 0.}, {0.06366307145956847, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.30085273905316984`, 0.}, {0.30085273905316984`, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.540615458930743, 0.}, {0.540615458930743, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.6285623384406963, 0.}, {0.6285623384406963, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.7670396582349713, 0.}, {0.7670396582349713, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{1., 0.}, {1., 0.2}}]}}, {}}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.5736144872315512, 0.}, {0.5736144872315512, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.9365882178369003, 0.}, {0.9365882178369003, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.10542036223945095`, 0.}, {0.10542036223945095`, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.703812919953293, 0.}, {0.703812919953293, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.8276990811233618, 0.}, {0.8276990811233618, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.9110683999583065, 0.}, {0.9110683999583065, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.04240624713877117, 0.}, {0.04240624713877117, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.8706169964428474, 0.}, {0.8706169964428474, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.8187056332379297, 0.}, {0.8187056332379297, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.25664594363853843`, 0.}, {0.25664594363853843`, 
           0.}}]}, {}}, {}}},
      AspectRatio->0.1,
      Axes->{True, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None},
      PlotRange->{{0, 1.01}, {-1, 1}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -98.18181818181819}, 
     ImageScaled[{0.5, 0.5}], {360., 35.999999999999986`}], InsetBox[
     GraphicsBox[{{{{{}, {}, 
          {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
           Opacity[1.], LineBox[CompressedData["
1:eJxF0X0s1AEcBvDDVnmdLKefGZFsmBinTUUqkXSVO6ImmbdlFC1aV21NOkte
IlbRaXROJXMnKhXuOHMqOs4dN113Tuf9cjHHZl6qrb7fZ3v27PP34xifTksy
JJFI1D/9u8eSpgYE05EBpH+ZbDgdryIoB/6bbCoraiKCwLv9tnEqiQjw3n4f
3gMiESx4IvQtJDLBOdn51+4Rd8CJmToijygDbykLrf41XwN+1+8dEmLPBUfn
KEaE+c3g9MYrHo8X34MXiod6DAz44J6Obr54fyc4hRFqfkbbBe4w9t6ovygC
17K71m13fQYHktue0Rt6wR4iRUu3mxgsDaTPvZzrB6eZpEpkXhLwF3lUm0XR
IJgeHK3WaKTgPVX5UVXOQ+DR9VLphVvD4PFQMZsslIN55SrGgOMImHPXKM/1
+jewPuHsTPJHBdg0KJfWaKME37QcN1PHqMBm7e6kYeoo2P/qyTXhCppVU8De
yVKDYyMpfcZhY+A3sqTS9iW0Xy/PcOLhD/COI8n60iAN2JfiW9I8gVYtFH5i
M8fBWp9wJuE9AXaZ9ZgxGER3OWdJMrInwfelsgSa8xRYRxeUGHahX0daH/a7
PA1m9+VUjlnNgJdFMTesOtGjJXy95aVZ8NLAPuK2hRacUeYkYLSibfqcLDWx
P/FfWf2q3Tp64Xx1mqJuDsyP4zItjuvAH8RpYcoT6LcBblsbwtH1dhwWNQpd
Ia9oKohHZ53KVZsw0O6B5/w316JduLZGwy/QTvbyntpX6O2rtIjgRvSmlqOp
zFa02pNSbjSIVjydjx2UoeXmXGe2HP111pV3SIlufe4gyp5Gt5C/F4Rr0U3M
CpqjDl2XYK0ULKI5Egm7eBlddbA4JW4FzeJRPb3W0I8cTPUbG+jf5AtD6w==

            "]]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0., 0.}, {0., 0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.06366307145956847, 0.}, {0.06366307145956847, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.30085273905316984`, 0.}, {0.30085273905316984`, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.540615458930743, 0.}, {0.540615458930743, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.6285623384406963, 0.}, {0.6285623384406963, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.7670396582349713, 0.}, {0.7670396582349713, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{1., 0.}, {1., 0.2}}]}}, {}}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.5570444548707494, 0.}, {0.5570444548707494, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.3844327398312444, 0.}, {0.3844327398312444, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.9141332554404238, 0.}, {0.9141332554404238, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.06381261546124684, 0.}, {0.06381261546124684, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.03923458314935546, 0.}, {0.03923458314935546, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.5033449453229839, 0.}, {0.5033449453229839, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.11151658842729395`, 0.}, {0.11151658842729395`, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.819515769912716, 0.}, {0.819515769912716, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.5292864969340143, 0.}, {0.5292864969340143, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.15065540195319782`, 0.}, {0.15065540195319782`, 
           0.}}]}, {}}, {}}},
      AspectRatio->0.1,
      Axes->{True, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None},
      PlotRange->{{0, 1.01}, {-1, 1}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -137.45454545454547`}, 
     ImageScaled[{0.5, 0.5}], {360., 36.000000000000014`}], InsetBox[
     GraphicsBox[{{{{{}, {}, 
          {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
           Opacity[1.], LineBox[CompressedData["
1:eJxF0X0s1AEcBvDDVnmdLKefGZFsmBinTUUqkXSVO6ImmbdlFC1aV21NOkte
IlbRaXROJXMnKhXuOHMqOs4dN113Tuf9cjHHZl6qrb7fZ3v27PP34xifTksy
JJFI1D/9u8eSpgYE05EBpH+ZbDgdryIoB/6bbCoraiKCwLv9tnEqiQjw3n4f
3gMiESx4IvQtJDLBOdn51+4Rd8CJmToijygDbykLrf41XwN+1+8dEmLPBUfn
KEaE+c3g9MYrHo8X34MXiod6DAz44J6Obr54fyc4hRFqfkbbBe4w9t6ovygC
17K71m13fQYHktue0Rt6wR4iRUu3mxgsDaTPvZzrB6eZpEpkXhLwF3lUm0XR
IJgeHK3WaKTgPVX5UVXOQ+DR9VLphVvD4PFQMZsslIN55SrGgOMImHPXKM/1
+jewPuHsTPJHBdg0KJfWaKME37QcN1PHqMBm7e6kYeoo2P/qyTXhCppVU8De
yVKDYyMpfcZhY+A3sqTS9iW0Xy/PcOLhD/COI8n60iAN2JfiW9I8gVYtFH5i
M8fBWp9wJuE9AXaZ9ZgxGER3OWdJMrInwfelsgSa8xRYRxeUGHahX0daH/a7
PA1m9+VUjlnNgJdFMTesOtGjJXy95aVZ8NLAPuK2hRacUeYkYLSibfqcLDWx
P/FfWf2q3Tp64Xx1mqJuDsyP4zItjuvAH8RpYcoT6LcBblsbwtH1dhwWNQpd
Ia9oKohHZ53KVZsw0O6B5/w316JduLZGwy/QTvbyntpX6O2rtIjgRvSmlqOp
zFa02pNSbjSIVjydjx2UoeXmXGe2HP111pV3SIlufe4gyp5Gt5C/F4Rr0U3M
CpqjDl2XYK0ULKI5Egm7eBlddbA4JW4FzeJRPb3W0I8cTPUbG+jf5AtD6w==

            "]]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0., 0.}, {0., 0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.06366307145956847, 0.}, {0.06366307145956847, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.30085273905316984`, 0.}, {0.30085273905316984`, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.540615458930743, 0.}, {0.540615458930743, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.6285623384406963, 0.}, {0.6285623384406963, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.7670396582349713, 0.}, {0.7670396582349713, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{1., 0.}, {1., 0.2}}]}}, {}}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.09080393088223793, 0.}, {0.09080393088223793, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.03790902847578148, 0.}, {0.03790902847578148, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.4018422938897497, 0.}, {0.4018422938897497, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.7816637921332581, 0.}, {0.7816637921332581, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.6262695130825715, 0.}, {0.6262695130825715, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.9914338380338199, 0.}, {0.9914338380338199, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.053943201564838894`, 0.}, {0.053943201564838894`, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.3756991013524429, 0.}, {0.3756991013524429, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.4755659540961339, 0.}, {0.4755659540961339, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.26671423748679235`, 0.}, {0.26671423748679235`, 
           0.}}]}, {}}, {}}},
      AspectRatio->0.1,
      Axes->{True, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None},
      PlotRange->{{0, 1.01}, {-1, 1}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -176.72727272727275`}, 
     ImageScaled[{0.5, 0.5}], {360., 36.00000000000003}], InsetBox[
     GraphicsBox[{{{{{}, {}, 
          {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
           Opacity[1.], LineBox[CompressedData["
1:eJxF0X0s1AEcBvDDVnmdLKefGZFsmBinTUUqkXSVO6ImmbdlFC1aV21NOkte
IlbRaXROJXMnKhXuOHMqOs4dN113Tuf9cjHHZl6qrb7fZ3v27PP34xifTksy
JJFI1D/9u8eSpgYE05EBpH+ZbDgdryIoB/6bbCoraiKCwLv9tnEqiQjw3n4f
3gMiESx4IvQtJDLBOdn51+4Rd8CJmToijygDbykLrf41XwN+1+8dEmLPBUfn
KEaE+c3g9MYrHo8X34MXiod6DAz44J6Obr54fyc4hRFqfkbbBe4w9t6ovygC
17K71m13fQYHktue0Rt6wR4iRUu3mxgsDaTPvZzrB6eZpEpkXhLwF3lUm0XR
IJgeHK3WaKTgPVX5UVXOQ+DR9VLphVvD4PFQMZsslIN55SrGgOMImHPXKM/1
+jewPuHsTPJHBdg0KJfWaKME37QcN1PHqMBm7e6kYeoo2P/qyTXhCppVU8De
yVKDYyMpfcZhY+A3sqTS9iW0Xy/PcOLhD/COI8n60iAN2JfiW9I8gVYtFH5i
M8fBWp9wJuE9AXaZ9ZgxGER3OWdJMrInwfelsgSa8xRYRxeUGHahX0daH/a7
PA1m9+VUjlnNgJdFMTesOtGjJXy95aVZ8NLAPuK2hRacUeYkYLSibfqcLDWx
P/FfWf2q3Tp64Xx1mqJuDsyP4zItjuvAH8RpYcoT6LcBblsbwtH1dhwWNQpd
Ia9oKohHZ53KVZsw0O6B5/w316JduLZGwy/QTvbyntpX6O2rtIjgRvSmlqOp
zFa02pNSbjSIVjydjx2UoeXmXGe2HP111pV3SIlufe4gyp5Gt5C/F4Rr0U3M
CpqjDl2XYK0ULKI5Egm7eBlddbA4JW4FzeJRPb3W0I8cTPUbG+jf5AtD6w==

            "]]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0., 0.}, {0., 0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.06366307145956847, 0.}, {0.06366307145956847, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.30085273905316984`, 0.}, {0.30085273905316984`, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.540615458930743, 0.}, {0.540615458930743, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.6285623384406963, 0.}, {0.6285623384406963, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.7670396582349713, 0.}, {0.7670396582349713, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{1., 0.}, {1., 0.2}}]}}, {}}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.24089649274754965`, 0.}, {0.24089649274754965`, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.5137777505813723, 0.}, {0.5137777505813723, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.1442420845233836, 0.}, {0.1442420845233836, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.5784041617634639, 0.}, {0.5784041617634639, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.681233756790413, 0.}, {0.681233756790413, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.8466824064669567, 0.}, {0.8466824064669567, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.8483393776863741, 0.}, {0.8483393776863741, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.9528923047627074, 0.}, {0.9528923047627074, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.77165378160753, 0.}, {0.77165378160753, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.37791814589633055`, 0.}, {0.37791814589633055`, 
           0.}}]}, {}}, {}}},
      AspectRatio->0.1,
      Axes->{True, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None},
      PlotRange->{{0, 1.01}, {-1, 1}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -216.}, 
     ImageScaled[{0.5, 0.5}], {360., 36.00000000000003}], InsetBox[
     GraphicsBox[{{{{{}, {}, 
          {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
           Opacity[1.], LineBox[CompressedData["
1:eJxF0X0s1AEcBvDDVnmdLKefGZFsmBinTUUqkXSVO6ImmbdlFC1aV21NOkte
IlbRaXROJXMnKhXuOHMqOs4dN113Tuf9cjHHZl6qrb7fZ3v27PP34xifTksy
JJFI1D/9u8eSpgYE05EBpH+ZbDgdryIoB/6bbCoraiKCwLv9tnEqiQjw3n4f
3gMiESx4IvQtJDLBOdn51+4Rd8CJmToijygDbykLrf41XwN+1+8dEmLPBUfn
KEaE+c3g9MYrHo8X34MXiod6DAz44J6Obr54fyc4hRFqfkbbBe4w9t6ovygC
17K71m13fQYHktue0Rt6wR4iRUu3mxgsDaTPvZzrB6eZpEpkXhLwF3lUm0XR
IJgeHK3WaKTgPVX5UVXOQ+DR9VLphVvD4PFQMZsslIN55SrGgOMImHPXKM/1
+jewPuHsTPJHBdg0KJfWaKME37QcN1PHqMBm7e6kYeoo2P/qyTXhCppVU8De
yVKDYyMpfcZhY+A3sqTS9iW0Xy/PcOLhD/COI8n60iAN2JfiW9I8gVYtFH5i
M8fBWp9wJuE9AXaZ9ZgxGER3OWdJMrInwfelsgSa8xRYRxeUGHahX0daH/a7
PA1m9+VUjlnNgJdFMTesOtGjJXy95aVZ8NLAPuK2hRacUeYkYLSibfqcLDWx
P/FfWf2q3Tp64Xx1mqJuDsyP4zItjuvAH8RpYcoT6LcBblsbwtH1dhwWNQpd
Ia9oKohHZ53KVZsw0O6B5/w316JduLZGwy/QTvbyntpX6O2rtIjgRvSmlqOp
zFa02pNSbjSIVjydjx2UoeXmXGe2HP111pV3SIlufe4gyp5Gt5C/F4Rr0U3M
CpqjDl2XYK0ULKI5Egm7eBlddbA4JW4FzeJRPb3W0I8cTPUbG+jf5AtD6w==

            "]]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0., 0.}, {0., 0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.06366307145956847, 0.}, {0.06366307145956847, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.30085273905316984`, 0.}, {0.30085273905316984`, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.540615458930743, 0.}, {0.540615458930743, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.6285623384406963, 0.}, {0.6285623384406963, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], 
           LineBox[{{0.7670396582349713, 0.}, {0.7670396582349713, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{1., 0.}, {1., 0.2}}]}}, {}}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.9927033521098807, 0.}, {0.9927033521098807, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.9092786512030941, 0.}, {0.9092786512030941, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.0991144911668167, 0.}, {0.0991144911668167, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.2144150806820848, 0.}, {0.2144150806820848, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.4159594821196728, 0.}, {0.4159594821196728, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.7095992898236076, 0.}, {0.7095992898236076, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.7274306806496835, 0.}, {0.7274306806496835, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.49846229929337516`, 0.}, {0.49846229929337516`, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.901866527515339, 0.}, {0.901866527515339, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.45348911561792726`, 0.}, {0.45348911561792726`, 
           0.}}]}, {}}, {}}},
      AspectRatio->0.1,
      Axes->{True, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None},
      PlotRange->{{0, 1.01}, {-1, 1}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -255.2727272727273}, 
     ImageScaled[{0.5, 0.5}], {360., 36.00000000000003}], InsetBox[
     GraphicsBox[{{{{{}, {}, 
          {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
           Opacity[1.], LineBox[CompressedData["
1:eJxF0X0s1AEcBvDDVnmdLKefGZFsmBinTUUqkXSVO6ImmbdlFC1aV21NOkte
IlbRaXROJXMnKhXuOHMqOs4dN113Tuf9cjHHZl6qrb7fZ3v27PP34xifTksy
JJFI1D/9u8eSpgYE05EBpH+ZbDgdryIoB/6bbCoraiKCwLv9tnEqiQjw3n4f
3gMiESx4IvQtJDLBOdn51+4Rd8CJmToijygDbykLrf41XwN+1+8dEmLPBUfn
KEaE+c3g9MYrHo8X34MXiod6DAz44J6Obr54fyc4hRFqfkbbBe4w9t6ovygC
17K71m13fQYHktue0Rt6wR4iRUu3mxgsDaTPvZzrB6eZpEpkXhLwF3lUm0XR
IJgeHK3WaKTgPVX5UVXOQ+DR9VLphVvD4PFQMZsslIN55SrGgOMImHPXKM/1
+jewPuHsTPJHBdg0KJfWaKME37QcN1PHqMBm7e6kYeoo2P/qyTXhCppVU8De
yVKDYyMpfcZhY+A3sqTS9iW0Xy/PcOLhD/COI8n60iAN2JfiW9I8gVYtFH5i
M8fBWp9wJuE9AXaZ9ZgxGER3OWdJMrInwfelsgSa8xRYRxeUGHahX0daH/a7
PA1m9+VUjlnNgJdFMTesOtGjJXy95aVZ8NLAPuK2hRacUeYkYLSibfqcLDWx
P/FfWf2q3Tp64Xx1mqJuDsyP4zItjuvAH8RpYcoT6LcBblsbwtH1dhwWNQpd
Ia9oKohHZ53KVZsw0O6B5/w316JduLZGwy/QTvbyntpX6O2rtIjgRvSmlqOp
zFa02pNSbjSIVjydjx2UoeXmXGe2HP111pV3SIlufe4gyp5Gt5C/F4Rr0U3M
CpqjDl2XYK0ULKI5Egm7eBlddbA4JW4FzeJRPb3W0I8cTPUbG+jf5AtD6w==

            "]]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0., 0.}, {0., 0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.06366307145956847, 0.}, {0.06366307145956847, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.30085273905316984`, 0.}, {0.30085273905316984`, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.540615458930743, 0.}, {0.540615458930743, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.6285623384406963, 0.}, {0.6285623384406963, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.7670396582349713, 0.}, {0.7670396582349713, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{1., 0.}, {1., 0.2}}]}}, {}}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.5406790612406451, 0.}, {0.5406790612406451, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.7180354339477097, 0.}, {0.7180354339477097, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.13922368237500993`, 0.}, {0.13922368237500993`, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.25579156481347876`, 0.}, {0.25579156481347876`, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.7911149774996702, 0.}, {0.7911149774996702, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.6174656576141717, 0.}, {0.6174656576141717, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.4100130542936866, 0.}, {0.4100130542936866, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.6408436888719806, 0.}, {0.6408436888719806, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.9456703784955753, 0.}, {0.9456703784955753, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.7901258683198533, 0.}, {0.7901258683198533, 
           0.}}]}, {}}, {}}},
      AspectRatio->0.1,
      Axes->{True, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None},
      PlotRange->{{0, 1.01}, {-1, 1}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -294.54545454545456`}, 
     ImageScaled[{0.5, 0.5}], {360., 36.}], InsetBox[
     GraphicsBox[{{{{{}, {}, 
          {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
           Opacity[1.], LineBox[CompressedData["
1:eJxF0X0s1AEcBvDDVnmdLKefGZFsmBinTUUqkXSVO6ImmbdlFC1aV21NOkte
IlbRaXROJXMnKhXuOHMqOs4dN113Tuf9cjHHZl6qrb7fZ3v27PP34xifTksy
JJFI1D/9u8eSpgYE05EBpH+ZbDgdryIoB/6bbCoraiKCwLv9tnEqiQjw3n4f
3gMiESx4IvQtJDLBOdn51+4Rd8CJmToijygDbykLrf41XwN+1+8dEmLPBUfn
KEaE+c3g9MYrHo8X34MXiod6DAz44J6Obr54fyc4hRFqfkbbBe4w9t6ovygC
17K71m13fQYHktue0Rt6wR4iRUu3mxgsDaTPvZzrB6eZpEpkXhLwF3lUm0XR
IJgeHK3WaKTgPVX5UVXOQ+DR9VLphVvD4PFQMZsslIN55SrGgOMImHPXKM/1
+jewPuHsTPJHBdg0KJfWaKME37QcN1PHqMBm7e6kYeoo2P/qyTXhCppVU8De
yVKDYyMpfcZhY+A3sqTS9iW0Xy/PcOLhD/COI8n60iAN2JfiW9I8gVYtFH5i
M8fBWp9wJuE9AXaZ9ZgxGER3OWdJMrInwfelsgSa8xRYRxeUGHahX0daH/a7
PA1m9+VUjlnNgJdFMTesOtGjJXy95aVZ8NLAPuK2hRacUeYkYLSibfqcLDWx
P/FfWf2q3Tp64Xx1mqJuDsyP4zItjuvAH8RpYcoT6LcBblsbwtH1dhwWNQpd
Ia9oKohHZ53KVZsw0O6B5/w316JduLZGwy/QTvbyntpX6O2rtIjgRvSmlqOp
zFa02pNSbjSIVjydjx2UoeXmXGe2HP111pV3SIlufe4gyp5Gt5C/F4Rr0U3M
CpqjDl2XYK0ULKI5Egm7eBlddbA4JW4FzeJRPb3W0I8cTPUbG+jf5AtD6w==

            "]]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0., 0.}, {0., 0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.06366307145956847, 0.}, {0.06366307145956847, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.30085273905316984`, 0.}, {0.30085273905316984`, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.540615458930743, 0.}, {0.540615458930743, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.6285623384406963, 0.}, {0.6285623384406963, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.7670396582349713, 0.}, {0.7670396582349713, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{1., 0.}, {1., 0.2}}]}}, {}}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.7355717678317573, 0.}, {0.7355717678317573, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.2025712573542917, 0.}, {0.2025712573542917, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.10995979639748277`, 0.}, {0.10995979639748277`, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.5719094918393277, 0.}, {0.5719094918393277, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.5295537626389801, 0.}, {0.5295537626389801, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.1496948832661349, 0.}, {0.1496948832661349, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.5241879363837114, 0.}, {0.5241879363837114, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.19011810194727907`, 0.}, {0.19011810194727907`, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.674513502287367, 0.}, {0.674513502287367, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.9696429805940363, 0.}, {0.9696429805940363, 
           0.}}]}, {}}, {}}},
      AspectRatio->0.1,
      Axes->{True, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None},
      PlotRange->{{0, 1.01}, {-1, 1}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -333.8181818181818}, 
     ImageScaled[{0.5, 0.5}], {360., 36.}], InsetBox[
     GraphicsBox[{{{{{}, {}, 
          {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
           Opacity[1.], LineBox[CompressedData["
1:eJxF0X0s1AEcBvDDVnmdLKefGZFsmBinTUUqkXSVO6ImmbdlFC1aV21NOkte
IlbRaXROJXMnKhXuOHMqOs4dN113Tuf9cjHHZl6qrb7fZ3v27PP34xifTksy
JJFI1D/9u8eSpgYE05EBpH+ZbDgdryIoB/6bbCoraiKCwLv9tnEqiQjw3n4f
3gMiESx4IvQtJDLBOdn51+4Rd8CJmToijygDbykLrf41XwN+1+8dEmLPBUfn
KEaE+c3g9MYrHo8X34MXiod6DAz44J6Obr54fyc4hRFqfkbbBe4w9t6ovygC
17K71m13fQYHktue0Rt6wR4iRUu3mxgsDaTPvZzrB6eZpEpkXhLwF3lUm0XR
IJgeHK3WaKTgPVX5UVXOQ+DR9VLphVvD4PFQMZsslIN55SrGgOMImHPXKM/1
+jewPuHsTPJHBdg0KJfWaKME37QcN1PHqMBm7e6kYeoo2P/qyTXhCppVU8De
yVKDYyMpfcZhY+A3sqTS9iW0Xy/PcOLhD/COI8n60iAN2JfiW9I8gVYtFH5i
M8fBWp9wJuE9AXaZ9ZgxGER3OWdJMrInwfelsgSa8xRYRxeUGHahX0daH/a7
PA1m9+VUjlnNgJdFMTesOtGjJXy95aVZ8NLAPuK2hRacUeYkYLSibfqcLDWx
P/FfWf2q3Tp64Xx1mqJuDsyP4zItjuvAH8RpYcoT6LcBblsbwtH1dhwWNQpd
Ia9oKohHZ53KVZsw0O6B5/w316JduLZGwy/QTvbyntpX6O2rtIjgRvSmlqOp
zFa02pNSbjSIVjydjx2UoeXmXGe2HP111pV3SIlufe4gyp5Gt5C/F4Rr0U3M
CpqjDl2XYK0ULKI5Egm7eBlddbA4JW4FzeJRPb3W0I8cTPUbG+jf5AtD6w==

            "]]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0., 0.}, {0., 0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.06366307145956847, 0.}, {0.06366307145956847, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.30085273905316984`, 0.}, {0.30085273905316984`, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.540615458930743, 0.}, {0.540615458930743, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.6285623384406963, 0.}, {0.6285623384406963, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{0.7670396582349713, 0.}, {0.7670396582349713, 
            0.2}}]}}, {}}, {{}, {{}, {}, 
          {GrayLevel[0], PointSize[0.019444444444444445`], AbsoluteThickness[
           3], LineBox[{{1., 0.}, {1., 0.2}}]}}, {}}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.8858187515115157, 0.}, {0.8858187515115157, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.5804507172745565, 0.}, {0.5804507172745565, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.320985955418678, 0.}, {0.320985955418678, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.9849811372444441, 0.}, {0.9849811372444441, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.9901692052389512, 0.}, {0.9901692052389512, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.7970509048766707, 0.}, {0.7970509048766707, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.05135697635068115, 0.}, {0.05135697635068115, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.714540889191805, 0.}, {0.714540889191805, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.25108224388896283`, 0.}, {0.25108224388896283`, 
           0.}}]}, {}}, {}}, {{}, {{}, 
         {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
          PointBox[{{0.6708924317255429, 0.}, {0.6708924317255429, 
           0.}}]}, {}}, {}}},
      AspectRatio->0.1,
      Axes->{True, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None},
      PlotRange->{{0, 1.01}, {-1, 1}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {189., -373.09090909090907`}, 
     ImageScaled[{0.5, 0.5}], {360., 36.}]}, {}},
  ContentSelectable->True,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.677570312298275*^9}]
}, Open  ]],

Cell["\<\
Abbildung 2.5 stellt drei H\[ADoubleDot]ufigkeitsverteilungen f\[UDoubleDot]r \
unterschiedliche Stichprobengr\[ODoubleDot]\[SZ]en sowie die \
tats\[ADoubleDot]chliche Verteilung dar. Der optische Eindruck aus Abb. 2.4 \
best\[ADoubleDot]tigt sich: Mit nur zehn Wiederholungen des Einzelereignisses \
lassen sich die Intervallgr\[ODoubleDot]\[SZ]en nur unzureichend \
nachzeichnen. Mit wachsender Zahl der Wiederholungen (Stichprobengr\
\[ODoubleDot]\[SZ]e) approximieren die relativen H\[ADoubleDot]ufigkeiten \
jedoch immer besser die Intervallgrenzen (Abb. 2.5d).\
\>", "Text",
 CellChangeTimes->{
  3.6745585660589886`*^9, {3.674558597741034*^9, 3.6745586263770757`*^9}, {
   3.677488962340289*^9, 3.6774889928559427`*^9}, {3.6774890276002035`*^9, 
   3.677489048554041*^9}, {3.677489087512309*^9, 3.6774890911315155`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "=", 
      RowBox[{"RandomReal", "[", "]"}]}], ",", " ", 
     RowBox[{
      RowBox[{"val", "[", "k", "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Position", "[", 
         RowBox[{
          RowBox[{"Sort", "[", 
           RowBox[{"Append", "[", 
            RowBox[{"cumDist", ",", "x"}], "]"}], "]"}], ",", "x"}], "]"}], 
        "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], " ", "-", "1"}]}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "1", ",", "10"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"valTab", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"val", "[", "k", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", "10"}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.62287727597674*^9, 3.622877287987947*^9}, {
  3.622877413928274*^9, 3.622877414497031*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "4", ",", "2", ",", "5", ",", "6", ",", "6", ",", "3", ",", "2", ",", "6", 
   ",", "5", ",", "3"}], "}"}]], "Output",
 CellChangeTimes->{3.677570312376275*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pl10", "=", 
  RowBox[{"BarChart", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"BinCounts", "[", 
      RowBox[{"valTab", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "7", ",", "1"}], "}"}]}], "]"}], "/", 
     RowBox[{"Length", "[", "valTab", "]"}]}], ",", " ", 
    RowBox[{"BarSpacing", "\[Rule]", "0"}], ",", 
    RowBox[{"ChartLabels", "\[Rule]", 
     RowBox[{"Range", "[", 
      RowBox[{"1", ",", "6"}], "]"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<Intervallnummer\>\"", ",", 
       "\"\<relative H\[ADoubleDot]ufigkeit\>\""}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSize", "\[Rule]", "8"}]}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.5", ",", "6.5"}], "}"}], ",", "Automatic"}], "}"}]}], ",", 
    RowBox[{"ChartStyle", "\[Rule]", "LightGray"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619168509396741*^9, 3.619168513814994*^9}, {
   3.6191687042948885`*^9, 3.619168740965986*^9}, {3.619168839439618*^9, 
   3.619168899389047*^9}, {3.619168988892166*^9, 3.6191690175158033`*^9}, 
   3.619169078611298*^9, {3.6191700613005047`*^9, 3.619170085765904*^9}, {
   3.6191703874021564`*^9, 3.61917041491473*^9}, {3.61917046613666*^9, 
   3.619170513842388*^9}, {3.6191705644022803`*^9, 3.619170567778474*^9}, {
   3.6191706046915846`*^9, 3.619170620042463*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{
   {Opacity[0], PointBox[{0.5, 0.}]}, {{}, 
    {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
     0.6579999999999999], Thickness[Small]}], 
     {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{0.5, 0.}, {1.5, 0.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{38.989999999999995`, 89.41}, {79.57660448996721, 
           80.07660448996721}}],
         StatusArea[#, 0]& ,
         TagBoxNote->"0"],
        StyleBox["0", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0, {}], "Tooltip"]& ]}, 
     {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{1.5, 0.}, {2.5, 0.2}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{88.91, 139.32999999999998`}, {-42.54691168701203, 
           80.07660448996721}}],
         StatusArea[#, 
          Rational[1, 5]]& ,
         TagBoxNote->"1/5"],
        StyleBox[
         FractionBox["1", "5"], {}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Rational[1, 5], {}], "Tooltip"]& ]}, 
     {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{2.5, 0.}, {3.5, 0.2}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{138.82999999999998`, 
           189.24999999999997`}, {-42.54691168701203, 80.07660448996721}}],
         StatusArea[#, 
          Rational[1, 5]]& ,
         TagBoxNote->"1/5"],
        StyleBox[
         FractionBox["1", "5"], {}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Rational[1, 5], {}], "Tooltip"]& ]}, 
     {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{3.5, 0.}, {4.5, 0.1}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{188.74999999999997`, 239.17}, {18.51484640147759, 
           80.07660448996721}}],
         StatusArea[#, 
          Rational[1, 10]]& ,
         TagBoxNote->"1/10"],
        StyleBox[
         FractionBox["1", "10"], {}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Rational[1, 10], {}], "Tooltip"]& ]}, 
     {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{4.5, 0.}, {5.5, 0.2}, "RoundingRadius" -> 0]},
          ImageSizeCache->{{238.67, 289.0899999999999}, {-42.54691168701203, 
           80.07660448996721}}],
         StatusArea[#, 
          Rational[1, 5]]& ,
         TagBoxNote->"1/5"],
        StyleBox[
         FractionBox["1", "5"], {}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Rational[1, 5], {}], "Tooltip"]& ]}, 
     {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{5.5, 0.}, {6.5, 0.3}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{288.5899999999999, 339.01}, {-103.60866977550164`,
            80.07660448996721}}],
         StatusArea[#, 
          Rational[3, 10]]& ,
         TagBoxNote->"3/10"],
        StyleBox[
         FractionBox["3", "10"], {}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Rational[3, 10], {}], "Tooltip"]& ]}}, {}, {}}, {}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0.5, 0.},
  BaseStyle->{FontFamily -> "Times", FontSize -> 8},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& )},
  Frame->True,
  FrameLabel->{{
     FormBox["\"relative H\[ADoubleDot]ufigkeit\"", TraditionalForm], None}, {
     FormBox["\"Intervallnummer\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {{{1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {1., 
       FormBox["1", TraditionalForm], 0}, {2., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
       FormBox["2", TraditionalForm], 0}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
       FormBox["3", TraditionalForm], 0}, {4., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
       FormBox["4", TraditionalForm], 0}, {5., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
       FormBox["5", TraditionalForm], 0}, {6., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
       FormBox["6", TraditionalForm], 0}}, {{1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{0.5, 6.5}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, 
     Scaled[0.05]}},
  Ticks->{None, Automatic}]], "Output",
 CellChangeTimes->{3.677570312735076*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"X", "=", 
      RowBox[{"RandomReal", "[", "]"}]}], ",", " ", 
     RowBox[{
      RowBox[{"val", "[", "k", "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Position", "[", 
         RowBox[{
          RowBox[{"Sort", "[", 
           RowBox[{"Append", "[", 
            RowBox[{"cumDist", ",", "X"}], "]"}], "]"}], ",", "X"}], "]"}], 
        "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], " ", "-", "1"}]}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "1", ",", "100"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"valTab", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"val", "[", "k", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", "100"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{3.622877500505814*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pl100", "=", 
  RowBox[{"BarChart", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"BinCounts", "[", 
      RowBox[{"valTab", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "7", ",", "1"}], "}"}]}], "]"}], "/", 
     RowBox[{"Length", "[", "valTab", "]"}]}], ",", " ", 
    RowBox[{"BarSpacing", "\[Rule]", "0"}], ",", 
    RowBox[{"ChartLabels", "\[Rule]", 
     RowBox[{"Range", "[", 
      RowBox[{"1", ",", "6"}], "]"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<Intervallnummer\>\"", ",", 
       "\"\<relative H\[ADoubleDot]ufigkeit\>\""}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSize", "\[Rule]", "8"}]}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.5", ",", "6.5"}], "}"}], ",", "Automatic"}], "}"}]}], ",", 
    RowBox[{"ChartStyle", "\[Rule]", "LightGray"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619168509396741*^9, 3.619168513814994*^9}, {
   3.6191687042948885`*^9, 3.619168740965986*^9}, {3.619168839439618*^9, 
   3.619168899389047*^9}, {3.619168988892166*^9, 3.6191690175158033`*^9}, 
   3.6191700570292606`*^9, 3.619170095028434*^9, 3.6191703838139515`*^9, {
   3.6191706278819113`*^9, 3.6191706280809226`*^9}, 3.6289184273526115`*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{
   {Opacity[0], PointBox[{0.5, 0.}]}, {{}, 
    {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
     0.6579999999999999], Thickness[Small]}], 
     {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{0.5, 0.}, {1.5, 0.06}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{38.99, 89.41}, {35.61213866625467, 
           80.0766044899672}}],
         StatusArea[#, 
          Rational[3, 50]]& ,
         TagBoxNote->"3/50"],
        StyleBox[
         FractionBox["3", "50"], {}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Rational[3, 50], {}], "Tooltip"]& ]}, 
     {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{1.5, 0.}, {2.5, 0.18}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{88.91, 139.33}, {-52.31679298117038, 
           80.0766044899672}}],
         StatusArea[#, 
          Rational[9, 50]]& ,
         TagBoxNote->"9/50"],
        StyleBox[
         FractionBox["9", "50"], {}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Rational[9, 50], {}], "Tooltip"]& ]}, 
     {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{2.5, 0.}, {3.5, 0.25}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{138.83, 189.25}, {-103.60866977550165`, 
           80.0766044899672}}],
         StatusArea[#, 
          Rational[1, 4]]& ,
         TagBoxNote->"1/4"],
        StyleBox[
         FractionBox["1", "4"], {}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Rational[1, 4], {}], "Tooltip"]& ]}, 
     {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{3.5, 0.}, {4.5, 0.14}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{188.75, 
           239.17000000000002`}, {-23.007149098695365`, 80.0766044899672}}],
         StatusArea[#, 
          Rational[7, 50]]& ,
         TagBoxNote->"7/50"],
        StyleBox[
         FractionBox["7", "50"], {}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Rational[7, 50], {}], "Tooltip"]& ]}, 
     {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{4.5, 0.}, {5.5, 0.14}, "RoundingRadius" -> 0]},
          ImageSizeCache->{{238.67000000000002`, 
           289.09000000000003`}, {-23.007149098695365`, 80.0766044899672}}],
         StatusArea[#, 
          Rational[7, 50]]& ,
         TagBoxNote->"7/50"],
        StyleBox[
         FractionBox["7", "50"], {}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Rational[7, 50], {}], "Tooltip"]& ]}, 
     {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{5.5, 0.}, {6.5, 0.23}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{288.59000000000003`, 
           339.01000000000005`}, {-88.95384783426414, 80.0766044899672}}],
         StatusArea[#, 
          Rational[23, 100]]& ,
         TagBoxNote->"23/100"],
        StyleBox[
         FractionBox["23", "100"], {}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Rational[23, 100], {}], "Tooltip"]& ]}}, {}, {}}, {}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0.5, 0.},
  BaseStyle->{FontFamily -> "Times", FontSize -> 8},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& )},
  Frame->True,
  FrameLabel->{{
     FormBox["\"relative H\[ADoubleDot]ufigkeit\"", TraditionalForm], None}, {
     FormBox["\"Intervallnummer\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {{{1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {1., 
       FormBox["1", TraditionalForm], 0}, {2., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
       FormBox["2", TraditionalForm], 0}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
       FormBox["3", TraditionalForm], 0}, {4., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
       FormBox["4", TraditionalForm], 0}, {5., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
       FormBox["5", TraditionalForm], 0}, {6., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
       FormBox["6", TraditionalForm], 0}}, {{1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{0.5, 6.5}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, 
     Scaled[0.05]}},
  Ticks->{None, Automatic}]], "Output",
 CellChangeTimes->{3.6775703132966766`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"X", "=", 
      RowBox[{"RandomReal", "[", "]"}]}], ",", " ", 
     RowBox[{
      RowBox[{"val", "[", "k", "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Position", "[", 
         RowBox[{
          RowBox[{"Sort", "[", 
           RowBox[{"Append", "[", 
            RowBox[{"cumDist", ",", "X"}], "]"}], "]"}], ",", "X"}], "]"}], 
        "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], " ", "-", "1"}]}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "1", ",", "1000"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"valTab", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"val", "[", "k", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", "1000"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{3.62287752652862*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pl1000", "=", 
  RowBox[{"BarChart", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"BinCounts", "[", 
      RowBox[{"valTab", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "7", ",", "1"}], "}"}]}], "]"}], "/", 
     RowBox[{"Length", "[", "valTab", "]"}]}], ",", " ", 
    RowBox[{"BarSpacing", "\[Rule]", "0"}], ",", 
    RowBox[{"ChartLabels", "\[Rule]", 
     RowBox[{"Range", "[", 
      RowBox[{"1", ",", "6"}], "]"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<Intervallnummer\>\"", ",", 
       "\"\<relative H\[ADoubleDot]ufigkeit\>\""}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSize", "\[Rule]", "8"}]}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.5", ",", "6.5"}], "}"}], ",", "Automatic"}], "}"}]}], ",", 
    RowBox[{"ChartStyle", "\[Rule]", "LightGray"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619168509396741*^9, 3.619168513814994*^9}, {
   3.6191687042948885`*^9, 3.619168740965986*^9}, {3.619168839439618*^9, 
   3.619168899389047*^9}, {3.619168988892166*^9, 3.6191690175158033`*^9}, 
   3.61916936520269*^9, 3.6191700533010473`*^9, 3.6191700986996436`*^9, {
   3.6191703745544214`*^9, 3.619170376746547*^9}, {3.619170633930257*^9, 
   3.61917063415327*^9}, {3.6289183800729065`*^9, 3.6289183837201157`*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{
   {Opacity[0], PointBox[{0.5, 0.}]}, {{}, 
    {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
     0.6579999999999999], Thickness[Small]}], 
     {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{0.5, 0.}, {1.5, 0.057}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{38.99, 89.41}, {37.131236062602454`, 
           80.0766044899672}}],
         StatusArea[#, 
          Rational[57, 1000]]& ,
         TagBoxNote->"57/1000"],
        StyleBox[
         FractionBox["57", "1000"], {}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Rational[57, 1000], {}], "Tooltip"]& ]}, 
     {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{1.5, 0.}, {2.5, 0.246}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{88.91, 139.33}, {-103.60866977550165`, 
           80.0766044899672}}],
         StatusArea[#, 
          Rational[123, 500]]& ,
         TagBoxNote->"123/500"],
        StyleBox[
         FractionBox["123", "500"], {}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Rational[123, 500], {}], "Tooltip"]& ]}, 
     {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{2.5, 0.}, {3.5, 0.241}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{138.83, 189.25}, {-99.8853918432767, 
           80.0766044899672}}],
         StatusArea[#, 
          Rational[241, 1000]]& ,
         TagBoxNote->"241/1000"],
        StyleBox[
         FractionBox["241", "1000"], {}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Rational[241, 1000], {}], "Tooltip"]& ]}, 
     {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{3.5, 0.}, {4.5, 0.077}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{188.75, 239.17000000000002`}, {22.23812433370255, 
           80.0766044899672}}],
         StatusArea[#, 
          Rational[77, 1000]]& ,
         TagBoxNote->"77/1000"],
        StyleBox[
         FractionBox["77", "1000"], {}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Rational[77, 1000], {}], "Tooltip"]& ]}, 
     {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{4.5, 0.}, {5.5, 0.148}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{238.67000000000002`, 
           289.09000000000003`}, {-30.632422303892113`, 80.0766044899672}}],
         StatusArea[#, 
          Rational[37, 250]]& ,
         TagBoxNote->"37/250"],
        StyleBox[
         FractionBox["37", "250"], {}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Rational[37, 250], {}], "Tooltip"]& ]}, 
     {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{5.5, 0.}, {6.5, 0.231}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{288.59000000000003`, 
           339.01000000000005`}, {-92.43883597882675, 80.0766044899672}}],
         StatusArea[#, 
          Rational[231, 1000]]& ,
         TagBoxNote->"231/1000"],
        StyleBox[
         FractionBox["231", "1000"], {}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Rational[231, 1000], {}], "Tooltip"]& ]}}, {}, {}}, {}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0.5, 0.},
  BaseStyle->{FontFamily -> "Times", FontSize -> 8},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& )},
  Frame->True,
  FrameLabel->{{
     FormBox["\"relative H\[ADoubleDot]ufigkeit\"", TraditionalForm], None}, {
     FormBox["\"Intervallnummer\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {{{1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {1., 
       FormBox["1", TraditionalForm], 0}, {2., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
       FormBox["2", TraditionalForm], 0}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
       FormBox["3", TraditionalForm], 0}, {4., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
       FormBox["4", TraditionalForm], 0}, {5., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
       FormBox["5", TraditionalForm], 0}, {6., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
       FormBox["6", TraditionalForm], 0}}, {{1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{0.5, 6.5}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, 
     Scaled[0.05]}},
  Ticks->{None, Automatic}]], "Output",
 CellChangeTimes->{3.6775703134994774`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Thread", "[", 
  RowBox[{"{", 
   RowBox[{"probDist", ",", 
    RowBox[{"Range", "[", 
     RowBox[{"2", ",", "7"}], "]"}]}], "}"}], "]"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.06366307145956847`", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.23718966759360136`", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.23976271987757325`", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.08794687950995327`", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.138477319794275`", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.23296034176502867`", ",", "7"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.677570313546277*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plws", "=", 
  RowBox[{"BarChart", "[", 
   RowBox[{"probDist", ",", " ", 
    RowBox[{"BarSpacing", "\[Rule]", "0"}], ",", 
    RowBox[{"ChartLabels", "\[Rule]", 
     RowBox[{"Range", "[", 
      RowBox[{"1", ",", "6"}], "]"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<Intervallnummer\>\"", ",", 
       "\"\<relative H\[ADoubleDot]ufigkeit\>\""}], "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSize", "\[Rule]", "8"}]}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.5", ",", "6.5"}], "}"}], ",", "Automatic"}], "}"}]}], ",", 
    RowBox[{"ChartStyle", "\[Rule]", "Gray"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619169352889986*^9, 3.619169379440504*^9}, 
   3.619169522434683*^9, {3.6191695724395432`*^9, 3.619169610040694*^9}, {
   3.6191700446065493`*^9, 3.6191700448515635`*^9}, 3.619170101794821*^9, {
   3.6191702952598867`*^9, 3.6191703581144814`*^9}, {3.6191706390905523`*^9, 
   3.619170643264791*^9}, 3.6289185331686635`*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{
   {Opacity[0], PointBox[{0.5, 0.}]}, {{}, 
    {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
     0.6579999999999999], Thickness[Small]}], 
     {GrayLevel[0.5], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0.5, 0.}, {1.5, 0.06366307145956847}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{38.99, 89.41}, {30.936277036816577`, 
           80.07660448996721}}],
         StatusArea[#, 0.06366307145956847]& ,
         TagBoxNote->"0.06366307145956847"],
        StyleBox["0.06366307145956847`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.06366307145956847, {}], "Tooltip"]& ]}, 
     {GrayLevel[0.5], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{1.5, 0.}, {2.5, 0.23718966759360136`}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{88.91, 139.33}, {-101.64278747078195`, 
           80.07660448996721}}],
         StatusArea[#, 0.23718966759360136`]& ,
         TagBoxNote->"0.23718966759360136"],
        StyleBox["0.23718966759360136`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.23718966759360136`, {}], "Tooltip"]& ]}, 
     {GrayLevel[0.5], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{2.5, 0.}, {3.5, 0.23976271987757325`}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{138.83, 189.25}, {-103.60866977550164`, 
           80.07660448996721}}],
         StatusArea[#, 0.23976271987757325`]& ,
         TagBoxNote->"0.23976271987757325"],
        StyleBox["0.23976271987757325`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.23976271987757325`, {}], "Tooltip"]& ]}, 
     {GrayLevel[0.5], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{3.5, 0.}, {4.5, 0.08794687950995327}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{188.75, 239.17000000000002`}, {
           12.382783648890452`, 80.07660448996721}}],
         StatusArea[#, 0.08794687950995327]& ,
         TagBoxNote->"0.08794687950995327"],
        StyleBox["0.08794687950995327`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.08794687950995327, {}], "Tooltip"]& ]}, 
     {GrayLevel[0.5], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{4.5, 0.}, {5.5, 0.138477319794275}, "RoundingRadius" -> 
            0]},
          
          ImageSizeCache->{{238.67000000000002`, 
           289.09000000000003`}, {-26.22385447635628, 80.07660448996721}}],
         StatusArea[#, 0.138477319794275]& ,
         TagBoxNote->"0.138477319794275"],
        StyleBox["0.138477319794275`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.138477319794275, {}], "Tooltip"]& ]}, 
     {GrayLevel[0.5], EdgeForm[{Opacity[0.6579999999999999], Thickness[
      Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{5.5, 0.}, {6.5, 0.23296034176502867`}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{288.59000000000003`, 
           339.01000000000005`}, {-98.4114668874122, 80.07660448996721}}],
         StatusArea[#, 0.23296034176502867`]& ,
         TagBoxNote->"0.23296034176502867"],
        StyleBox["0.23296034176502867`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.23296034176502867`, {}], "Tooltip"]& ]}}, {}, {}}, {}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0.5, 0.},
  BaseStyle->{FontFamily -> "Times", FontSize -> 8},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& )},
  Frame->True,
  FrameLabel->{{
     FormBox["\"relative H\[ADoubleDot]ufigkeit\"", TraditionalForm], None}, {
     FormBox["\"Intervallnummer\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {{{1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {1., 
       FormBox["1", TraditionalForm], 0}, {2., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
       FormBox["2", TraditionalForm], 0}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
       FormBox["3", TraditionalForm], 0}, {4., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
       FormBox["4", TraditionalForm], 0}, {5., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
       FormBox["5", TraditionalForm], 0}, {6., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
       FormBox["6", TraditionalForm], 0}}, {{1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{0.5, 6.5}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, 
     Scaled[0.05]}},
  Ticks->{None, Automatic}]], "Output",
 CellChangeTimes->{3.6775703137022777`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"pl10", ",", "pl100"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"pl1000", ",", "plws"}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.61916939911263*^9, 3.6191694825234003`*^9}, {
   3.6191699861892085`*^9, 3.619169987507284*^9}, {3.6191701237470765`*^9, 
   3.619170124018092*^9}, {3.619170201370516*^9, 3.6191702035166388`*^9}, {
   3.6191704440493965`*^9, 3.619170449415704*^9}, 3.6775561525733213`*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{
        {Opacity[0], PointBox[{0.5, 0.}]}, {{}, 
         {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
          0.6579999999999999], Thickness[Small]}], 
          {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                RectangleBox[{0.5, 0.}, {1.5, 0.}, "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{45.24986308349508, 
                63.69614528146984}, {-29.928672687215187`, \
-29.428672687215187`}}],
              StatusArea[#, 0]& ,
              TagBoxNote->"0"],
             StyleBox["0", {}, StripOnInput -> False]],
            Annotation[#, 
             Style[0, {}], "Tooltip"]& ]}, 
          {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                RectangleBox[{1.5, 0.}, {2.5, 0.2}, "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{63.19614528146984, 
                81.6424274794446}, {-73.83217998531225, \
-29.428672687215183`}}],
              StatusArea[#, 
               Rational[1, 5]]& ,
              TagBoxNote->"1/5"],
             StyleBox[
              FractionBox["1", "5"], {}, StripOnInput -> False]],
            Annotation[#, 
             Style[
              Rational[1, 5], {}], "Tooltip"]& ]}, 
          {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                RectangleBox[{2.5, 0.}, {3.5, 0.2}, "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{81.1424274794446, 
                99.58870967741936}, {-73.83217998531225, \
-29.428672687215183`}}],
              StatusArea[#, 
               Rational[1, 5]]& ,
              TagBoxNote->"1/5"],
             StyleBox[
              FractionBox["1", "5"], {}, StripOnInput -> False]],
            Annotation[#, 
             Style[
              Rational[1, 5], {}], "Tooltip"]& ]}, 
          {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                RectangleBox[{3.5, 0.}, {4.5, 0.1}, "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{99.08870967741936, 
                117.53499187539413`}, {-51.880426336263724`, \
-29.428672687215187`}}],
              StatusArea[#, 
               Rational[1, 10]]& ,
              TagBoxNote->"1/10"],
             StyleBox[
              FractionBox["1", "10"], {}, StripOnInput -> False]],
            Annotation[#, 
             Style[
              Rational[1, 10], {}], "Tooltip"]& ]}, 
          {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                RectangleBox[{4.5, 0.}, {5.5, 0.2}, "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{117.03499187539413`, 
                135.4812740733689}, {-73.83217998531225, \
-29.428672687215183`}}],
              StatusArea[#, 
               Rational[1, 5]]& ,
              TagBoxNote->"1/5"],
             StyleBox[
              FractionBox["1", "5"], {}, StripOnInput -> False]],
            Annotation[#, 
             Style[
              Rational[1, 5], {}], "Tooltip"]& ]}, 
          {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                RectangleBox[{5.5, 0.}, {6.5, 0.3}, "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{134.9812740733689, 
                153.42755627134366`}, {-95.78393363436078, \
-29.428672687215183`}}],
              StatusArea[#, 
               Rational[3, 10]]& ,
              TagBoxNote->"3/10"],
             StyleBox[
              FractionBox["3", "10"], {}, StripOnInput -> False]],
            Annotation[#, 
             Style[
              Rational[3, 10], {}], "Tooltip"]& ]}}, {}, {}}, {}, {}, {}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{False, False},
       AxesLabel->{None, None},
       AxesOrigin->{0.5, 0.},
       BaseStyle->{FontFamily -> "Times", FontSize -> 8},
       CoordinatesToolOptions:>{"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )},
       Frame->True,
       FrameLabel->{{
          FormBox["\"relative H\[ADoubleDot]ufigkeit\"", TraditionalForm], 
          None}, {
          FormBox["\"Intervallnummer\"", TraditionalForm], None}},
       FrameTicks->{{Automatic, Automatic}, {{{1., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {1., 
            FormBox["1", TraditionalForm], 0}, {2., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
            FormBox["2", TraditionalForm], 0}, {3., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
            FormBox["3", TraditionalForm], 0}, {4., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
            FormBox["4", TraditionalForm], 0}, {5., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
            FormBox["5", TraditionalForm], 0}, {6., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
            FormBox["6", TraditionalForm], 0}}, {{1., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}}}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       PlotRange->{{0.5, 6.5}, {All, All}},
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {None, 
          Scaled[0.05]}},
       Ticks->{None, Automatic}], {192., -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{
        {Opacity[0], PointBox[{0.5, 0.}]}, {{}, 
         {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
          0.6579999999999999], Thickness[Small]}], 
          {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                RectangleBox[{0.5, 0.}, {1.5, 0.06}, "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{45.249863083495086`, 
                63.69614528146985}, {-45.73393531453013, \
-29.428672687215183`}}],
              StatusArea[#, 
               Rational[3, 50]]& ,
              TagBoxNote->"3/50"],
             StyleBox[
              FractionBox["3", "50"], {}, StripOnInput -> False]],
            Annotation[#, 
             Style[
              Rational[3, 50], {}], "Tooltip"]& ]}, 
          {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                RectangleBox[{1.5, 0.}, {2.5, 0.18}, "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{63.19614528146985, 
                81.64242747944462}, {-77.34446056916002, \
-29.428672687215183`}}],
              StatusArea[#, 
               Rational[9, 50]]& ,
              TagBoxNote->"9/50"],
             StyleBox[
              FractionBox["9", "50"], {}, StripOnInput -> False]],
            Annotation[#, 
             Style[
              Rational[9, 50], {}], "Tooltip"]& ]}, 
          {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                RectangleBox[{2.5, 0.}, {3.5, 0.25}, "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{81.14242747944462, 
                99.58870967741936}, {-95.78393363436078, \
-29.428672687215183`}}],
              StatusArea[#, 
               Rational[1, 4]]& ,
              TagBoxNote->"1/4"],
             StyleBox[
              FractionBox["1", "4"], {}, StripOnInput -> False]],
            Annotation[#, 
             Style[
              Rational[1, 4], {}], "Tooltip"]& ]}, 
          {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                RectangleBox[{3.5, 0.}, {4.5, 0.14}, "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{99.08870967741936, 
                117.53499187539413`}, {-66.80761881761671, \
-29.428672687215183`}}],
              StatusArea[#, 
               Rational[7, 50]]& ,
              TagBoxNote->"7/50"],
             StyleBox[
              FractionBox["7", "50"], {}, StripOnInput -> False]],
            Annotation[#, 
             Style[
              Rational[7, 50], {}], "Tooltip"]& ]}, 
          {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                RectangleBox[{4.5, 0.}, {5.5, 0.14}, "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{117.03499187539413`, 
                135.48127407336887`}, {-66.80761881761671, \
-29.428672687215183`}}],
              StatusArea[#, 
               Rational[7, 50]]& ,
              TagBoxNote->"7/50"],
             StyleBox[
              FractionBox["7", "50"], {}, StripOnInput -> False]],
            Annotation[#, 
             Style[
              Rational[7, 50], {}], "Tooltip"]& ]}, 
          {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                RectangleBox[{5.5, 0.}, {6.5, 0.23}, "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{134.98127407336887`, 
                153.42755627134363`}, {-90.51551275858913, \
-29.428672687215183`}}],
              StatusArea[#, 
               Rational[23, 100]]& ,
              TagBoxNote->"23/100"],
             StyleBox[
              FractionBox["23", "100"], {}, StripOnInput -> False]],
            Annotation[#, 
             Style[
              Rational[23, 100], {}], "Tooltip"]& ]}}, {}, {}}, {}, {}, {}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{False, False},
       AxesLabel->{None, None},
       AxesOrigin->{0.5, 0.},
       BaseStyle->{FontFamily -> "Times", FontSize -> 8},
       CoordinatesToolOptions:>{"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )},
       Frame->True,
       FrameLabel->{{
          FormBox["\"relative H\[ADoubleDot]ufigkeit\"", TraditionalForm], 
          None}, {
          FormBox["\"Intervallnummer\"", TraditionalForm], None}},
       FrameTicks->{{Automatic, Automatic}, {{{1., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {1., 
            FormBox["1", TraditionalForm], 0}, {2., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
            FormBox["2", TraditionalForm], 0}, {3., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
            FormBox["3", TraditionalForm], 0}, {4., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
            FormBox["4", TraditionalForm], 0}, {5., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
            FormBox["5", TraditionalForm], 0}, {6., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
            FormBox["6", TraditionalForm], 0}}, {{1., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}}}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       PlotRange->{{0.5, 6.5}, {All, All}},
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {None, 
          Scaled[0.05]}},
       Ticks->{None, Automatic}], {576., -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[{
        {Opacity[0], PointBox[{0.5, 0.}]}, {{}, 
         {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
          0.6579999999999999], Thickness[Small]}], 
          {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                RectangleBox[{0.5, 0.}, {1.5, 0.057}, "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{45.24986308349507, 
                63.69614528146984}, {-45.18781851643183, -29.42867268721517}}],
              StatusArea[#, 
               Rational[57, 1000]]& ,
              TagBoxNote->"57/1000"],
             StyleBox[
              FractionBox["57", "1000"], {}, StripOnInput -> False]],
            Annotation[#, 
             Style[
              Rational[57, 1000], {}], "Tooltip"]& ]}, 
          {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                RectangleBox[{1.5, 0.}, {2.5, 0.246}, "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{63.19614528146984, 
                81.64242747944459}, {-95.78393363436076, -29.42867268721517}}],
              StatusArea[#, 
               Rational[123, 500]]& ,
              TagBoxNote->"123/500"],
             StyleBox[
              FractionBox["123", "500"], {}, StripOnInput -> False]],
            Annotation[#, 
             Style[
              Rational[123, 500], {}], "Tooltip"]& ]}, 
          {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                RectangleBox[{2.5, 0.}, {3.5, 0.241}, "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{81.14242747944459, 
                99.58870967741936}, {-94.44541207039438, -29.42867268721517}}],
              StatusArea[#, 
               Rational[241, 1000]]& ,
              TagBoxNote->"241/1000"],
             StyleBox[
              FractionBox["241", "1000"], {}, StripOnInput -> False]],
            Annotation[#, 
             Style[
              Rational[241, 1000], {}], "Tooltip"]& ]}, 
          {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                RectangleBox[{3.5, 0.}, {4.5, 0.077}, "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{99.08870967741936, 
                117.53499187539413`}, {-50.54190477229733, \
-29.42867268721517}}],
              StatusArea[#, 
               Rational[77, 1000]]& ,
              TagBoxNote->"77/1000"],
             StyleBox[
              FractionBox["77", "1000"], {}, StripOnInput -> False]],
            Annotation[#, 
             Style[
              Rational[77, 1000], {}], "Tooltip"]& ]}, 
          {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                RectangleBox[{4.5, 0.}, {5.5, 0.148}, "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{117.03499187539413`, 
                135.48127407336887`}, {-69.54891098061984, \
-29.42867268721517}}],
              StatusArea[#, 
               Rational[37, 250]]& ,
              TagBoxNote->"37/250"],
             StyleBox[
              FractionBox["37", "250"], {}, StripOnInput -> False]],
            Annotation[#, 
             Style[
              Rational[37, 250], {}], "Tooltip"]& ]}, 
          {GrayLevel[0.85], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                RectangleBox[{5.5, 0.}, {6.5, 0.231}, "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{134.98127407336887`, 
                153.42755627134363`}, {-91.76836894246165, \
-29.42867268721517}}],
              StatusArea[#, 
               Rational[231, 1000]]& ,
              TagBoxNote->"231/1000"],
             StyleBox[
              FractionBox["231", "1000"], {}, StripOnInput -> False]],
            Annotation[#, 
             Style[
              Rational[231, 1000], {}], "Tooltip"]& ]}}, {}, {}}, {}, {}, {}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{False, False},
       AxesLabel->{None, None},
       AxesOrigin->{0.5, 0.},
       BaseStyle->{FontFamily -> "Times", FontSize -> 8},
       CoordinatesToolOptions:>{"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )},
       Frame->True,
       FrameLabel->{{
          FormBox["\"relative H\[ADoubleDot]ufigkeit\"", TraditionalForm], 
          None}, {
          FormBox["\"Intervallnummer\"", TraditionalForm], None}},
       FrameTicks->{{Automatic, Automatic}, {{{1., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {1., 
            FormBox["1", TraditionalForm], 0}, {2., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
            FormBox["2", TraditionalForm], 0}, {3., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
            FormBox["3", TraditionalForm], 0}, {4., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
            FormBox["4", TraditionalForm], 0}, {5., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
            FormBox["5", TraditionalForm], 0}, {6., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
            FormBox["6", TraditionalForm], 0}}, {{1., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}}}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       PlotRange->{{0.5, 6.5}, {All, All}},
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {None, 
          Scaled[0.05]}},
       Ticks->{None, Automatic}], {192., -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{
        {Opacity[0], PointBox[{0.5, 0.}]}, {{}, 
         {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
          0.6579999999999999], Thickness[Small]}], 
          {GrayLevel[0.5], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                
                RectangleBox[{0.5, 0.}, {1.5, 0.06366307145956847}, 
                 "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{45.52098309202093, 
                63.876891953820405`}, {-47.32685485892071, \
-29.42867268721517}}],
              StatusArea[#, 0.06366307145956847]& ,
              TagBoxNote->"0.06366307145956847"],
             StyleBox["0.06366307145956847`", {}, StripOnInput -> False]],
            Annotation[#, 
             Style[0.06366307145956847, {}], "Tooltip"]& ]}, 
          {GrayLevel[0.5], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                
                RectangleBox[{1.5, 0.}, {2.5, 0.23718966759360136`}, 
                 "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{63.376891953820405`, 
                81.73280081561987}, {-94.74912434670746, -29.42867268721517}}],
              StatusArea[#, 0.23718966759360136`]& ,
              TagBoxNote->"0.23718966759360136"],
             StyleBox["0.23718966759360136`", {}, StripOnInput -> False]],
            Annotation[#, 
             Style[0.23718966759360136`, {}], "Tooltip"]& ]}, 
          {GrayLevel[0.5], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                
                RectangleBox[{2.5, 0.}, {3.5, 0.23976271987757325`}, 
                 "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{81.23280081561987, 
                99.58870967741936}, {-95.45230173585206, -29.42867268721517}}],
              StatusArea[#, 0.23976271987757325`]& ,
              TagBoxNote->"0.23976271987757325"],
             StyleBox["0.23976271987757325`", {}, StripOnInput -> False]],
            Annotation[#, 
             Style[0.23976271987757325`, {}], "Tooltip"]& ]}, 
          {GrayLevel[0.5], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                
                RectangleBox[{3.5, 0.}, {4.5, 0.08794687950995327}, 
                 "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{99.08870967741936, 
                117.44461853921885`}, {-53.963262851765435`, \
-29.42867268721517}}],
              StatusArea[#, 0.08794687950995327]& ,
              TagBoxNote->"0.08794687950995327"],
             StyleBox["0.08794687950995327`", {}, StripOnInput -> False]],
            Annotation[#, 
             Style[0.08794687950995327, {}], "Tooltip"]& ]}, 
          {GrayLevel[0.5], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                
                RectangleBox[{4.5, 0.}, {5.5, 0.138477319794275}, 
                 "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{116.94461853921885`, 
                135.30052740101834`}, {-67.77248985146252, \
-29.42867268721517}}],
              StatusArea[#, 0.138477319794275]& ,
              TagBoxNote->"0.138477319794275"],
             StyleBox["0.138477319794275`", {}, StripOnInput -> False]],
            Annotation[#, 
             Style[0.138477319794275, {}], "Tooltip"]& ]}, 
          {GrayLevel[0.5], EdgeForm[{Opacity[0.6579999999999999], Thickness[
           Small]}], 
           TagBox[
            TooltipBox[
             TagBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                
                RectangleBox[{5.5, 0.}, {6.5, 0.23296034176502867`}, 
                 "RoundingRadius" -> 0]},
               
               ImageSizeCache->{{134.80052740101834`, 
                153.1564362628178}, {-93.59331172972213, -29.42867268721517}}],
              StatusArea[#, 0.23296034176502867`]& ,
              TagBoxNote->"0.23296034176502867"],
             StyleBox["0.23296034176502867`", {}, StripOnInput -> False]],
            Annotation[#, 
             Style[0.23296034176502867`, {}], 
             "Tooltip"]& ]}}, {}, {}}, {}, {}, {}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{False, False},
       AxesLabel->{None, None},
       AxesOrigin->{0.5, 0.},
       BaseStyle->{FontFamily -> "Times", FontSize -> 8},
       CoordinatesToolOptions:>{"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )},
       Frame->True,
       FrameLabel->{{
          FormBox["\"relative H\[ADoubleDot]ufigkeit\"", TraditionalForm], 
          None}, {
          FormBox["\"Intervallnummer\"", TraditionalForm], None}},
       FrameTicks->{{Automatic, Automatic}, {{{1., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {1., 
            FormBox["1", TraditionalForm], 0}, {2., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
            FormBox["2", TraditionalForm], 0}, {3., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
            FormBox["3", TraditionalForm], 0}, {4., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
            FormBox["4", TraditionalForm], 0}, {5., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
            FormBox["5", TraditionalForm], 0}, {6., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
            FormBox["6", TraditionalForm], 0}}, {{1., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
            FormBox[
             InterpretationBox[
              StyleBox[
               
               GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                Baseline], "CacheGraphics" -> False], 
              Spacer[0]], TraditionalForm], {0.004, 0}}}}},
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       PlotRange->{{0.5, 6.5}, {All, All}},
       PlotRangePadding->{{
          Scaled[0.02], 
          Scaled[0.02]}, {None, 
          Scaled[0.05]}},
       Ticks->{None, Automatic}], {576., -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}}, {}},
  ContentSelectable->True,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.6775703139362783`*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{507, 900},
WindowMargins->{{751, Automatic}, {81, Automatic}},
FrontEndVersion->"10.4 for Microsoft Windows (64-bit) (April 11, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 870, 36, 182, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1453, 60, 295, 9, 94, "Subtitle"],
Cell[1751, 71, 774, 15, 201, "Text"],
Cell[CellGroupData[{
Cell[2550, 90, 285, 7, 31, "Input"],
Cell[2838, 99, 272, 6, 52, "Output"]
}, Open  ]],
Cell[3125, 108, 206, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[3356, 116, 146, 4, 31, "Input"],
Cell[3505, 122, 280, 6, 52, "Output"]
}, Open  ]],
Cell[3800, 131, 836, 25, 144, "Text"],
Cell[CellGroupData[{
Cell[4661, 160, 91, 2, 31, "Input"],
Cell[4755, 164, 72, 1, 31, "Output"]
}, Open  ]],
Cell[4842, 168, 332, 10, 49, "Text"],
Cell[CellGroupData[{
Cell[5199, 182, 60, 1, 31, "Input"],
Cell[5262, 185, 74, 1, 31, "Output"]
}, Open  ]],
Cell[5351, 189, 2269, 79, 359, "Text"],
Cell[CellGroupData[{
Cell[7645, 272, 134, 3, 31, "Input"],
Cell[7782, 277, 269, 6, 52, "Output"]
}, Open  ]],
Cell[8066, 286, 136, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[8227, 291, 583, 17, 52, "Input"],
Cell[8813, 310, 1821, 40, 222, "Output"]
}, Open  ]],
Cell[10649, 353, 137, 1, 30, "Text"],
Cell[10789, 356, 1135, 29, 112, "Input"],
Cell[11927, 387, 811, 19, 163, "Text"],
Cell[CellGroupData[{
Cell[12763, 410, 457, 13, 112, "Input"],
Cell[13223, 425, 2987, 59, 222, "Output"]
}, Open  ]],
Cell[16225, 487, 391, 8, 87, "Text"],
Cell[CellGroupData[{
Cell[16641, 499, 223, 4, 31, "Input"],
Cell[16867, 505, 88, 1, 31, "Output"]
}, Open  ]],
Cell[16970, 509, 129, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[17124, 514, 548, 16, 72, "Input"],
Cell[17675, 532, 3183, 62, 222, "Output"]
}, Open  ]],
Cell[20873, 597, 1108, 26, 201, "Text"],
Cell[CellGroupData[{
Cell[22006, 627, 365, 10, 52, "Input"],
Cell[22374, 639, 72, 1, 31, "Output"]
}, Open  ]],
Cell[22461, 643, 1034, 17, 239, "Text"],
Cell[23498, 662, 1447, 35, 168, "Input"],
Cell[CellGroupData[{
Cell[24970, 701, 847, 21, 108, "Input"],
Cell[25820, 724, 50276, 896, 361, "Output"]
}, Open  ]],
Cell[76111, 1623, 837, 13, 163, "Text"],
Cell[CellGroupData[{
Cell[76973, 1640, 1047, 31, 128, "Input"],
Cell[78023, 1673, 202, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[78262, 1683, 1680, 39, 228, "Input"],
Cell[79945, 1724, 9009, 251, 242, "Output"]
}, Open  ]],
Cell[88969, 1978, 1003, 32, 128, "Input"],
Cell[CellGroupData[{
Cell[89997, 2014, 1559, 37, 228, "Input"],
Cell[91559, 2053, 9091, 254, 242, "Output"]
}, Open  ]],
Cell[100665, 2310, 1004, 32, 128, "Input"],
Cell[CellGroupData[{
Cell[101694, 2346, 1632, 38, 228, "Input"],
Cell[103329, 2386, 9178, 255, 242, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[112544, 2646, 237, 7, 47, "Input"],
Cell[112784, 2655, 561, 15, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[113382, 2675, 1382, 32, 208, "Input"],
Cell[114767, 2709, 9277, 248, 242, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[124081, 2962, 588, 13, 47, "Input"],
Cell[124672, 2977, 43165, 1086, 263, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

